! file src/equations_module.f90
!
! Copyright 2009,2010 Dalton Harvie (daltonh@unimelb.edu.au)
! 
! This file is part of arb finite volume solver, referred to as `arb'.
! 
! arb is a software package designed to solve arbitrary partial
! differential equations on unstructured meshes using the finite volume
! method.  Primarily it consists of fortran source code, perl source
! code and shell scripts.  arb replies on certain third party software
! to run, most notably the computer algebra system maxima
! <http://maxima.sourceforge.net/> which is released under the GNU GPL.
! 
! The copyright of arb is held by Dalton Harvie.
! 
! arb is released under the GNU GPL.  arb is free software: you can
! redistribute it and/or modify it under the terms of the GNU General
! Public License (version 3) as published by the Free Software Foundation.
! You should have received a copy of the GNU General Public License
! along with arb (see file license/gpl.txt after unpacking).  If not,
! see <http://www.gnu.org/licenses/>.
! 
! arb is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
! FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
! for more details.
! 
! For full details of arb's license see the license directory.
! 
! The current homepage for the arb finite volume solver project is
! <http://www.chemeng.unimelb.edu.au/people/staff/daltonh/downloads/arb>.
!
!-------------------------------------------------------------------------
module equations_module

!----------------------------------------------------------------------------
contains

!----------------------------------------------------------------------------

subroutine allocate_meta_arrays

! here we allocate array elements of the meta data that corresponds to the input files

use general_module
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine allocate_meta_arrays'

! allocate meta arrays

! allocate var and compound arrays
allocate(var(85))
allocate(compound(75))

!constant: <Re> -> var[1] -> var(1) -> var(1)%funk(1)%v
var(1)%name='<Re>'
var(1)%multiplier=1.d0
var(1)%units='1'
var(1)%centring='none'
var(1)%type='constant'
var(1)%rank='scalar'
var(1)%region=''
var(1)%compound_name='<Re>'
allocate(var(1)%component(1))
var(1)%component=[ 1 ]
var(1)%output=.false.

!constant: <Sc> -> var[2] -> var(2) -> var(2)%funk(1)%v
var(2)%name='<Sc>'
var(2)%multiplier=1.d0
var(2)%units='1'
var(2)%centring='none'
var(2)%type='constant'
var(2)%rank='scalar'
var(2)%region=''
var(2)%compound_name='<Sc>'
allocate(var(2)%component(1))
var(2)%component=[ 2 ]
var(2)%output=.false.

!constant: <B> -> var[3] -> var(3) -> var(3)%funk(1)%v
var(3)%name='<B>'
var(3)%multiplier=1.d0
var(3)%units='1'
var(3)%centring='none'
var(3)%type='constant'
var(3)%rank='scalar'
var(3)%region=''
var(3)%compound_name='<B>'
allocate(var(3)%component(1))
var(3)%component=[ 3 ]
var(3)%output=.false.

!constant: <K> -> var[4] -> var(4) -> var(4)%funk(1)%v
var(4)%name='<K>'
var(4)%multiplier=1.d0
var(4)%units='1'
var(4)%centring='none'
var(4)%type='constant'
var(4)%rank='scalar'
var(4)%region=''
var(4)%compound_name='<K>'
allocate(var(4)%component(1))
var(4)%component=[ 4 ]
var(4)%output=.false.

!constant: <S> -> var[5] -> var(5) -> var(5)%funk(1)%v
var(5)%name='<S>'
var(5)%multiplier=1.d0
var(5)%units='1'
var(5)%centring='none'
var(5)%type='constant'
var(5)%rank='scalar'
var(5)%region=''
var(5)%compound_name='<S>'
allocate(var(5)%component(1))
var(5)%component=[ 5 ]
var(5)%output=.false.

!constant: <I_total> -> var[6] -> var(6) -> var(6)%funk(1)%v
var(6)%name='<I_total>'
var(6)%multiplier=1.d0
var(6)%units='1'
var(6)%centring='none'
var(6)%type='constant'
var(6)%rank='scalar'
var(6)%region=''
var(6)%compound_name='<I_total>'
allocate(var(6)%component(1))
var(6)%component=[ 6 ]
var(6)%output=.false.

!constant: <C_{Rhie-Chow}> -> var[7] -> var(7) -> var(7)%funk(1)%v
var(7)%name='<C_{Rhie-Chow}>'
var(7)%multiplier=1.d0
var(7)%units='1'
var(7)%centring='none'
var(7)%type='constant'
var(7)%rank='scalar'
var(7)%region=''
var(7)%compound_name='<C_{Rhie-Chow}>'
allocate(var(7)%component(1))
var(7)%component=[ 7 ]
var(7)%output=.false.

!constant: <adv_limiter> -> var[8] -> var(8) -> var(8)%funk(1)%v
var(8)%name='<adv_limiter>'
var(8)%multiplier=1.d0
var(8)%units='1'
var(8)%centring='none'
var(8)%type='constant'
var(8)%rank='scalar'
var(8)%region=''
var(8)%compound_name='<adv_limiter>'
allocate(var(8)%component(1))
var(8)%component=[ 8 ]
var(8)%output=.false.

!constant: <ion adv_limiter> -> var[9] -> var(9) -> var(9)%funk(1)%v
var(9)%name='<ion adv_limiter>'
var(9)%multiplier=1.d0
var(9)%units='1'
var(9)%centring='none'
var(9)%type='constant'
var(9)%rank='scalar'
var(9)%region=''
var(9)%compound_name='<ion adv_limiter>'
allocate(var(9)%component(1))
var(9)%component=[ 9 ]
var(9)%output=.false.

!constant: <n_min> -> var[10] -> var(10) -> var(10)%funk(1)%v
var(10)%name='<n_min>'
var(10)%multiplier=1.d0
var(10)%units='1'
var(10)%centring='none'
var(10)%type='constant'
var(10)%rank='scalar'
var(10)%region=''
var(10)%compound_name='<n_min>'
allocate(var(10)%component(1))
var(10)%component=[ 10 ]
var(10)%output=.false.

!independent: <u[l=1]> -> var[i,11] -> var(i,11) -> var(11)%funk(nsvar(11,i))%v
var(11)%name='<u[l=1]>'
var(11)%multiplier=1.d0
var(11)%units='1'
var(11)%centring='cell'
var(11)%type='independent'
var(11)%rank='vector'
var(11)%region='<all cells>'
var(11)%compound_name='<u>'
allocate(var(11)%component(3))
var(11)%component=[ 11 , 12 , 0 ]
var(11)%output=.false.
var(11)%magnitude=1.d0

!independent: <u[l=2]> -> var[i,12] -> var(i,12) -> var(12)%funk(nsvar(12,i))%v
var(12)%name='<u[l=2]>'
var(12)%multiplier=1.d0
var(12)%units='1'
var(12)%centring='cell'
var(12)%type='independent'
var(12)%rank='vector'
var(12)%region='<all cells>'
var(12)%compound_name='<u>'
allocate(var(12)%component(3))
var(12)%component=[ 11 , 12 , 0 ]
var(12)%output=.false.
var(12)%magnitude=1.d0

!independent: <p> -> var[i,13] -> var(i,13) -> var(13)%funk(nsvar(13,i))%v
var(13)%name='<p>'
var(13)%multiplier=1.d0
var(13)%units='1'
var(13)%centring='cell'
var(13)%type='independent'
var(13)%rank='scalar'
var(13)%region='<all cells>'
var(13)%compound_name='<p>'
allocate(var(13)%component(1))
var(13)%component=[ 13 ]
var(13)%output=.false.
var(13)%magnitude=1.d+6

!independent: <p_in> -> var[14] -> var(14) -> var(14)%funk(1)%v
var(14)%name='<p_in>'
var(14)%multiplier=1.d0
var(14)%units='Pa'
var(14)%centring='none'
var(14)%type='independent'
var(14)%rank='scalar'
var(14)%region=''
var(14)%compound_name='<p_in>'
allocate(var(14)%component(1))
var(14)%component=[ 14 ]
var(14)%output=.false.
var(14)%magnitude=1.d0

!independent: <n+> -> var[i,15] -> var(i,15) -> var(15)%funk(nsvar(15,i))%v
var(15)%name='<n+>'
var(15)%multiplier=1.d0
var(15)%units='1'
var(15)%centring='cell'
var(15)%type='independent'
var(15)%rank='scalar'
var(15)%region='<all cells>'
var(15)%compound_name='<n+>'
allocate(var(15)%component(1))
var(15)%component=[ 15 ]
var(15)%output=.false.
var(15)%magnitude=1.d0

!independent: <n-> -> var[i,16] -> var(i,16) -> var(16)%funk(nsvar(16,i))%v
var(16)%name='<n->'
var(16)%multiplier=1.d0
var(16)%units='1'
var(16)%centring='cell'
var(16)%type='independent'
var(16)%rank='scalar'
var(16)%region='<all cells>'
var(16)%compound_name='<n->'
allocate(var(16)%component(1))
var(16)%component=[ 16 ]
var(16)%output=.false.
var(16)%magnitude=1.d0

!independent: <dUdx inlet> -> var[17] -> var(17) -> var(17)%funk(1)%v
var(17)%name='<dUdx inlet>'
var(17)%multiplier=1.d0
var(17)%units='1'
var(17)%centring='none'
var(17)%type='independent'
var(17)%rank='scalar'
var(17)%region=''
var(17)%compound_name='<dUdx inlet>'
allocate(var(17)%component(1))
var(17)%component=[ 17 ]
var(17)%output=.false.
var(17)%magnitude=1.d0

!independent: <U> -> var[i,18] -> var(i,18) -> var(18)%funk(nsvar(18,i))%v
var(18)%name='<U>'
var(18)%multiplier=1.d0
var(18)%units='1'
var(18)%centring='cell'
var(18)%type='independent'
var(18)%rank='scalar'
var(18)%region='<all cells>'
var(18)%compound_name='<U>'
allocate(var(18)%component(1))
var(18)%component=[ 18 ]
var(18)%output=.false.
var(18)%magnitude=1.d+2

!dependent: <tau[l=1,1]> -> var[j,19] -> var(j,19) -> var(19)%funk(nsvar(19,j))%v
var(19)%name='<tau[l=1,1]>'
var(19)%multiplier=1.d0
var(19)%units='1'
var(19)%centring='face'
var(19)%type='dependent'
var(19)%rank='tensor'
var(19)%region='<all faces>'
var(19)%compound_name='<tau>'
allocate(var(19)%component(9))
var(19)%component=[ 19 , 20 , 0 , 22 , 21 , 0 , 0 , 0 , 0 ]
var(19)%output=.false.

!dependent: <tau[l=1,2]> -> var[j,20] -> var(j,20) -> var(20)%funk(nsvar(20,j))%v
var(20)%name='<tau[l=1,2]>'
var(20)%multiplier=1.d0
var(20)%units='1'
var(20)%centring='face'
var(20)%type='dependent'
var(20)%rank='tensor'
var(20)%region='<all faces>'
var(20)%compound_name='<tau>'
allocate(var(20)%component(9))
var(20)%component=[ 19 , 20 , 0 , 22 , 21 , 0 , 0 , 0 , 0 ]
var(20)%output=.false.

!dependent: <tau[l=2,2]> -> var[j,21] -> var(j,21) -> var(21)%funk(nsvar(21,j))%v
var(21)%name='<tau[l=2,2]>'
var(21)%multiplier=1.d0
var(21)%units='1'
var(21)%centring='face'
var(21)%type='dependent'
var(21)%rank='tensor'
var(21)%region='<all faces>'
var(21)%compound_name='<tau>'
allocate(var(21)%component(9))
var(21)%component=[ 19 , 20 , 0 , 22 , 21 , 0 , 0 , 0 , 0 ]
var(21)%output=.false.

!dependent: <tau[l=2,1]> -> var[j,22] -> var(j,22) -> var(22)%funk(nsvar(22,j))%v
var(22)%name='<tau[l=2,1]>'
var(22)%multiplier=1.d0
var(22)%units='1'
var(22)%centring='face'
var(22)%type='dependent'
var(22)%rank='tensor'
var(22)%region='<all faces>'
var(22)%compound_name='<tau>'
allocate(var(22)%component(9))
var(22)%component=[ 19 , 20 , 0 , 22 , 21 , 0 , 0 , 0 , 0 ]
var(22)%output=.false.

!dependent: <graddivp[l=1]> -> var[i,23] -> var(i,23) -> var(23)%funk(nsvar(23,i))%v
var(23)%name='<graddivp[l=1]>'
var(23)%multiplier=1.d0
var(23)%units='1'
var(23)%centring='cell'
var(23)%type='dependent'
var(23)%rank='vector'
var(23)%region='<all cells>'
var(23)%compound_name='<graddivp>'
allocate(var(23)%component(3))
var(23)%component=[ 23 , 24 , 0 ]
var(23)%output=.false.

!dependent: <graddivp[l=2]> -> var[i,24] -> var(i,24) -> var(24)%funk(nsvar(24,i))%v
var(24)%name='<graddivp[l=2]>'
var(24)%multiplier=1.d0
var(24)%units='1'
var(24)%centring='cell'
var(24)%type='dependent'
var(24)%rank='vector'
var(24)%region='<all cells>'
var(24)%compound_name='<graddivp>'
allocate(var(24)%component(3))
var(24)%component=[ 23 , 24 , 0 ]
var(24)%output=.false.

!dependent: <p_error> -> var[j,25] -> var(j,25) -> var(25)%funk(nsvar(25,j))%v
var(25)%name='<p_error>'
var(25)%multiplier=1.d0
var(25)%units='1'
var(25)%centring='face'
var(25)%type='dependent'
var(25)%rank='scalar'
var(25)%region='<all faces>'
var(25)%compound_name='<p_error>'
allocate(var(25)%component(1))
var(25)%component=[ 25 ]
var(25)%output=.false.

!dependent: <u_f_{correction}> -> var[j,26] -> var(j,26) -> var(26)%funk(nsvar(26,j))%v
var(26)%name='<u_f_{correction}>'
var(26)%multiplier=1.d0
var(26)%units='1'
var(26)%centring='face'
var(26)%type='dependent'
var(26)%rank='scalar'
var(26)%region='<all faces>'
var(26)%compound_name='<u_f_{correction}>'
allocate(var(26)%component(1))
var(26)%component=[ 26 ]
var(26)%output=.false.

!dependent: <u_f> -> var[j,27] -> var(j,27) -> var(27)%funk(nsvar(27,j))%v
var(27)%name='<u_f>'
var(27)%multiplier=1.d0
var(27)%units='1'
var(27)%centring='face'
var(27)%type='dependent'
var(27)%rank='scalar'
var(27)%region='<all faces>'
var(27)%compound_name='<u_f>'
allocate(var(27)%component(1))
var(27)%component=[ 27 ]
var(27)%output=.false.

!dependent: <J_f[l=1]> -> var[j,28] -> var(j,28) -> var(28)%funk(nsvar(28,j))%v
var(28)%name='<J_f[l=1]>'
var(28)%multiplier=1.d0
var(28)%units='1'
var(28)%centring='face'
var(28)%type='dependent'
var(28)%rank='vector'
var(28)%region='<all faces>'
var(28)%compound_name='<J_f>'
allocate(var(28)%component(3))
var(28)%component=[ 28 , 29 , 0 ]
var(28)%output=.false.

!dependent: <J_f[l=2]> -> var[j,29] -> var(j,29) -> var(29)%funk(nsvar(29,j))%v
var(29)%name='<J_f[l=2]>'
var(29)%multiplier=1.d0
var(29)%units='1'
var(29)%centring='face'
var(29)%type='dependent'
var(29)%rank='vector'
var(29)%region='<all faces>'
var(29)%compound_name='<J_f>'
allocate(var(29)%component(3))
var(29)%component=[ 28 , 29 , 0 ]
var(29)%output=.false.

!dependent: <u_av_calc> -> var[30] -> var(30) -> var(30)%funk(1)%v
var(30)%name='<u_av_calc>'
var(30)%multiplier=1.d0
var(30)%units='1'
var(30)%centring='none'
var(30)%type='dependent'
var(30)%rank='scalar'
var(30)%region=''
var(30)%compound_name='<u_av_calc>'
allocate(var(30)%component(1))
var(30)%component=[ 30 ]
var(30)%output=.false.

!dependent: <n+ lim> -> var[i,31] -> var(i,31) -> var(31)%funk(nsvar(31,i))%v
var(31)%name='<n+ lim>'
var(31)%multiplier=1.d0
var(31)%units='1'
var(31)%centring='cell'
var(31)%type='dependent'
var(31)%rank='scalar'
var(31)%region='<all cells>'
var(31)%compound_name='<n+ lim>'
allocate(var(31)%component(1))
var(31)%component=[ 31 ]
var(31)%output=.false.

!dependent: <n- lim> -> var[i,32] -> var(i,32) -> var(32)%funk(nsvar(32,i))%v
var(32)%name='<n- lim>'
var(32)%multiplier=1.d0
var(32)%units='1'
var(32)%centring='cell'
var(32)%type='dependent'
var(32)%rank='scalar'
var(32)%region='<all cells>'
var(32)%compound_name='<n- lim>'
allocate(var(32)%component(1))
var(32)%component=[ 32 ]
var(32)%output=.false.

!dependent: <ion+ limiter> -> var[i,33] -> var(i,33) -> var(33)%funk(nsvar(33,i))%v
var(33)%name='<ion+ limiter>'
var(33)%multiplier=1.d0
var(33)%units='1'
var(33)%centring='cell'
var(33)%type='dependent'
var(33)%rank='scalar'
var(33)%region='<all cells>'
var(33)%compound_name='<ion+ limiter>'
allocate(var(33)%component(1))
var(33)%component=[ 33 ]
var(33)%output=.true.

!dependent: <ion- limiter> -> var[i,34] -> var(i,34) -> var(34)%funk(nsvar(34,i))%v
var(34)%name='<ion- limiter>'
var(34)%multiplier=1.d0
var(34)%units='1'
var(34)%centring='cell'
var(34)%type='dependent'
var(34)%rank='scalar'
var(34)%region='<all cells>'
var(34)%compound_name='<ion- limiter>'
allocate(var(34)%component(1))
var(34)%component=[ 34 ]
var(34)%output=.true.

!dependent: <n+_adv_f> -> var[j,35] -> var(j,35) -> var(35)%funk(nsvar(35,j))%v
var(35)%name='<n+_adv_f>'
var(35)%multiplier=1.d0
var(35)%units='1'
var(35)%centring='face'
var(35)%type='dependent'
var(35)%rank='scalar'
var(35)%region='<all faces>'
var(35)%compound_name='<n+_adv_f>'
allocate(var(35)%component(1))
var(35)%component=[ 35 ]
var(35)%output=.true.

!dependent: <n-_adv_f> -> var[j,36] -> var(j,36) -> var(36)%funk(nsvar(36,j))%v
var(36)%name='<n-_adv_f>'
var(36)%multiplier=1.d0
var(36)%units='1'
var(36)%centring='face'
var(36)%type='dependent'
var(36)%rank='scalar'
var(36)%region='<all faces>'
var(36)%compound_name='<n-_adv_f>'
allocate(var(36)%component(1))
var(36)%component=[ 36 ]
var(36)%output=.true.

!dependent: <J+_f> -> var[j,37] -> var(j,37) -> var(37)%funk(nsvar(37,j))%v
var(37)%name='<J+_f>'
var(37)%multiplier=1.d0
var(37)%units='1'
var(37)%centring='face'
var(37)%type='dependent'
var(37)%rank='scalar'
var(37)%region='<all faces>'
var(37)%compound_name='<J+_f>'
allocate(var(37)%component(1))
var(37)%component=[ 37 ]
var(37)%output=.false.

!dependent: <J-_f> -> var[j,38] -> var(j,38) -> var(38)%funk(nsvar(38,j))%v
var(38)%name='<J-_f>'
var(38)%multiplier=1.d0
var(38)%units='1'
var(38)%centring='face'
var(38)%type='dependent'
var(38)%rank='scalar'
var(38)%region='<all faces>'
var(38)%compound_name='<J-_f>'
allocate(var(38)%component(1))
var(38)%component=[ 38 ]
var(38)%output=.false.

!dependent: <I+> -> var[39] -> var(39) -> var(39)%funk(1)%v
var(39)%name='<I+>'
var(39)%multiplier=1.d0
var(39)%units='1'
var(39)%centring='none'
var(39)%type='dependent'
var(39)%rank='scalar'
var(39)%region=''
var(39)%compound_name='<I+>'
allocate(var(39)%component(1))
var(39)%component=[ 39 ]
var(39)%output=.false.

!dependent: <I-> -> var[40] -> var(40) -> var(40)%funk(1)%v
var(40)%name='<I->'
var(40)%multiplier=1.d0
var(40)%units='1'
var(40)%centring='none'
var(40)%type='dependent'
var(40)%rank='scalar'
var(40)%region=''
var(40)%compound_name='<I->'
allocate(var(40)%component(1))
var(40)%component=[ 40 ]
var(40)%output=.false.

!dependent: <I_total_calc> -> var[41] -> var(41) -> var(41)%funk(1)%v
var(41)%name='<I_total_calc>'
var(41)%multiplier=1.d0
var(41)%units='1'
var(41)%centring='none'
var(41)%type='dependent'
var(41)%rank='scalar'
var(41)%region=''
var(41)%compound_name='<I_total_calc>'
allocate(var(41)%component(1))
var(41)%component=[ 41 ]
var(41)%output=.false.

!dependent: <dUdx outlet> -> var[42] -> var(42) -> var(42)%funk(1)%v
var(42)%name='<dUdx outlet>'
var(42)%multiplier=1.d0
var(42)%units='1'
var(42)%centring='none'
var(42)%type='dependent'
var(42)%rank='scalar'
var(42)%region=''
var(42)%compound_name='<dUdx outlet>'
allocate(var(42)%component(1))
var(42)%component=[ 42 ]
var(42)%output=.false.

!equation: <continuity> -> var[i,43] -> var(i,43) -> var(43)%funk(nsvar(43,i))%v
var(43)%name='<continuity>'
var(43)%multiplier=1.d0
var(43)%units='1'
var(43)%centring='cell'
var(43)%type='equation'
var(43)%rank='scalar'
var(43)%region='<domain>'
var(43)%compound_name='<continuity>'
allocate(var(43)%component(1))
var(43)%component=[ 43 ]
var(43)%output=.false.

!equation: <momentum[l=1]> -> var[i,44] -> var(i,44) -> var(44)%funk(nsvar(44,i))%v
var(44)%name='<momentum[l=1]>'
var(44)%multiplier=1.d0
var(44)%units='1'
var(44)%centring='cell'
var(44)%type='equation'
var(44)%rank='vector'
var(44)%region='<domain>'
var(44)%compound_name='<momentum>'
allocate(var(44)%component(3))
var(44)%component=[ 44 , 45 , 0 ]
var(44)%output=.false.

!equation: <momentum[l=2]> -> var[i,45] -> var(i,45) -> var(45)%funk(nsvar(45,i))%v
var(45)%name='<momentum[l=2]>'
var(45)%multiplier=1.d0
var(45)%units='1'
var(45)%centring='cell'
var(45)%type='equation'
var(45)%rank='vector'
var(45)%region='<domain>'
var(45)%compound_name='<momentum>'
allocate(var(45)%component(3))
var(45)%component=[ 44 , 45 , 0 ]
var(45)%output=.false.

!equation: <wall noflux> -> var[j,46] -> var(j,46) -> var(46)%funk(nsvar(46,j))%v
var(46)%name='<wall noflux>'
var(46)%multiplier=1.d0
var(46)%units='1'
var(46)%centring='face'
var(46)%type='equation'
var(46)%rank='scalar'
var(46)%region='<walls>'
var(46)%compound_name='<wall noflux>'
allocate(var(46)%component(1))
var(46)%component=[ 46 ]
var(46)%output=.false.

!equation: <wall noslip> -> var[j,47] -> var(j,47) -> var(47)%funk(nsvar(47,j))%v
var(47)%name='<wall noslip>'
var(47)%multiplier=1.d0
var(47)%units='1'
var(47)%centring='face'
var(47)%type='equation'
var(47)%rank='scalar'
var(47)%region='<walls>'
var(47)%compound_name='<wall noslip>'
allocate(var(47)%component(1))
var(47)%component=[ 47 ]
var(47)%output=.false.

!equation: <wall p extrapolation> -> var[j,48] -> var(j,48) -> var(48)%funk(nsvar(48,j))%v
var(48)%name='<wall p extrapolation>'
var(48)%multiplier=1.d0
var(48)%units='1'
var(48)%centring='face'
var(48)%type='equation'
var(48)%rank='scalar'
var(48)%region='<walls>'
var(48)%compound_name='<wall p extrapolation>'
allocate(var(48)%component(1))
var(48)%component=[ 48 ]
var(48)%output=.false.

!equation: <outlet fully developed> -> var[j,49] -> var(j,49) -> var(49)%funk(nsvar(49,j))%v
var(49)%name='<outlet fully developed>'
var(49)%multiplier=1.d0
var(49)%units='1'
var(49)%centring='face'
var(49)%type='equation'
var(49)%rank='scalar'
var(49)%region='<outlet>'
var(49)%compound_name='<outlet fully developed>'
allocate(var(49)%component(1))
var(49)%component=[ 49 ]
var(49)%output=.false.

!equation: <outlet noslip> -> var[j,50] -> var(j,50) -> var(50)%funk(nsvar(50,j))%v
var(50)%name='<outlet noslip>'
var(50)%multiplier=1.d0
var(50)%units='1'
var(50)%centring='face'
var(50)%type='equation'
var(50)%rank='scalar'
var(50)%region='<outlet>'
var(50)%compound_name='<outlet noslip>'
allocate(var(50)%component(1))
var(50)%component=[ 50 ]
var(50)%output=.false.

!equation: <outlet p> -> var[j,51] -> var(j,51) -> var(51)%funk(nsvar(51,j))%v
var(51)%name='<outlet p>'
var(51)%multiplier=1.d0
var(51)%units='1'
var(51)%centring='face'
var(51)%type='equation'
var(51)%rank='scalar'
var(51)%region='<outlet>'
var(51)%compound_name='<outlet p>'
allocate(var(51)%component(1))
var(51)%component=[ 51 ]
var(51)%output=.false.

!equation: <inlet fully developed> -> var[j,52] -> var(j,52) -> var(52)%funk(nsvar(52,j))%v
var(52)%name='<inlet fully developed>'
var(52)%multiplier=1.d0
var(52)%units='1'
var(52)%centring='face'
var(52)%type='equation'
var(52)%rank='scalar'
var(52)%region='<inlet>'
var(52)%compound_name='<inlet fully developed>'
allocate(var(52)%component(1))
var(52)%component=[ 52 ]
var(52)%output=.false.

!equation: <inlet noslip> -> var[j,53] -> var(j,53) -> var(53)%funk(nsvar(53,j))%v
var(53)%name='<inlet noslip>'
var(53)%multiplier=1.d0
var(53)%units='1'
var(53)%centring='face'
var(53)%type='equation'
var(53)%rank='scalar'
var(53)%region='<inlet>'
var(53)%compound_name='<inlet noslip>'
allocate(var(53)%component(1))
var(53)%component=[ 53 ]
var(53)%output=.false.

!equation: <p_in for flowrate> -> var[54] -> var(54) -> var(54)%funk(1)%v
var(54)%name='<p_in for flowrate>'
var(54)%multiplier=1.d0
var(54)%units='1'
var(54)%centring='none'
var(54)%type='equation'
var(54)%rank='scalar'
var(54)%region=''
var(54)%compound_name='<p_in for flowrate>'
allocate(var(54)%component(1))
var(54)%component=[ 54 ]
var(54)%output=.false.

!equation: <inlet flowrate> -> var[j,55] -> var(j,55) -> var(55)%funk(nsvar(55,j))%v
var(55)%name='<inlet flowrate>'
var(55)%multiplier=1.d0
var(55)%units='1'
var(55)%centring='face'
var(55)%type='equation'
var(55)%rank='scalar'
var(55)%region='<inlet>'
var(55)%compound_name='<inlet flowrate>'
allocate(var(55)%component(1))
var(55)%component=[ 55 ]
var(55)%output=.false.

!equation: <velocity symmetry [l=1]> -> var[j,56] -> var(j,56) -> var(56)%funk(nsvar(56,j))%v
var(56)%name='<velocity symmetry [l=1]>'
var(56)%multiplier=1.d0
var(56)%units='1'
var(56)%centring='face'
var(56)%type='equation'
var(56)%rank='vector'
var(56)%region='<centreline>'
var(56)%compound_name='<velocity symmetry >'
allocate(var(56)%component(3))
var(56)%component=[ 56 , 57 , 0 ]
var(56)%output=.false.

!equation: <velocity symmetry [l=2]> -> var[j,57] -> var(j,57) -> var(57)%funk(nsvar(57,j))%v
var(57)%name='<velocity symmetry [l=2]>'
var(57)%multiplier=1.d0
var(57)%units='1'
var(57)%centring='face'
var(57)%type='equation'
var(57)%rank='vector'
var(57)%region='<centreline>'
var(57)%compound_name='<velocity symmetry >'
allocate(var(57)%component(3))
var(57)%component=[ 56 , 57 , 0 ]
var(57)%output=.false.

!equation: <pressure symmetry> -> var[j,58] -> var(j,58) -> var(58)%funk(nsvar(58,j))%v
var(58)%name='<pressure symmetry>'
var(58)%multiplier=1.d0
var(58)%units='1'
var(58)%centring='face'
var(58)%type='equation'
var(58)%rank='scalar'
var(58)%region='<centreline>'
var(58)%compound_name='<pressure symmetry>'
allocate(var(58)%component(1))
var(58)%component=[ 58 ]
var(58)%output=.false.

!equation: <ion+ continuity> -> var[i,59] -> var(i,59) -> var(59)%funk(nsvar(59,i))%v
var(59)%name='<ion+ continuity>'
var(59)%multiplier=1.d0
var(59)%units='1'
var(59)%centring='cell'
var(59)%type='equation'
var(59)%rank='scalar'
var(59)%region='<domain>'
var(59)%compound_name='<ion+ continuity>'
allocate(var(59)%component(1))
var(59)%component=[ 59 ]
var(59)%output=.false.

!equation: <ion- continuity> -> var[i,60] -> var(i,60) -> var(60)%funk(nsvar(60,i))%v
var(60)%name='<ion- continuity>'
var(60)%multiplier=1.d0
var(60)%units='1'
var(60)%centring='cell'
var(60)%type='equation'
var(60)%rank='scalar'
var(60)%region='<domain>'
var(60)%compound_name='<ion- continuity>'
allocate(var(60)%component(1))
var(60)%component=[ 60 ]
var(60)%output=.false.

!equation: <ion+ symmetry> -> var[j,61] -> var(j,61) -> var(61)%funk(nsvar(61,j))%v
var(61)%name='<ion+ symmetry>'
var(61)%multiplier=1.d0
var(61)%units='1'
var(61)%centring='face'
var(61)%type='equation'
var(61)%rank='scalar'
var(61)%region='<centreline>'
var(61)%compound_name='<ion+ symmetry>'
allocate(var(61)%component(1))
var(61)%component=[ 61 ]
var(61)%output=.false.

!equation: <ion- symmetry> -> var[j,62] -> var(j,62) -> var(62)%funk(nsvar(62,j))%v
var(62)%name='<ion- symmetry>'
var(62)%multiplier=1.d0
var(62)%units='1'
var(62)%centring='face'
var(62)%type='equation'
var(62)%rank='scalar'
var(62)%region='<centreline>'
var(62)%compound_name='<ion- symmetry>'
allocate(var(62)%component(1))
var(62)%component=[ 62 ]
var(62)%output=.false.

!equation: <ion+ outlet> -> var[j,63] -> var(j,63) -> var(63)%funk(nsvar(63,j))%v
var(63)%name='<ion+ outlet>'
var(63)%multiplier=1.d0
var(63)%units='1'
var(63)%centring='face'
var(63)%type='equation'
var(63)%rank='scalar'
var(63)%region='<outlet>'
var(63)%compound_name='<ion+ outlet>'
allocate(var(63)%component(1))
var(63)%component=[ 63 ]
var(63)%output=.false.

!equation: <ion- outlet> -> var[j,64] -> var(j,64) -> var(64)%funk(nsvar(64,j))%v
var(64)%name='<ion- outlet>'
var(64)%multiplier=1.d0
var(64)%units='1'
var(64)%centring='face'
var(64)%type='equation'
var(64)%rank='scalar'
var(64)%region='<outlet>'
var(64)%compound_name='<ion- outlet>'
allocate(var(64)%component(1))
var(64)%component=[ 64 ]
var(64)%output=.false.

!equation: <ion+ walls> -> var[j,65] -> var(j,65) -> var(65)%funk(nsvar(65,j))%v
var(65)%name='<ion+ walls>'
var(65)%multiplier=1.d0
var(65)%units='1'
var(65)%centring='face'
var(65)%type='equation'
var(65)%rank='scalar'
var(65)%region='<walls>'
var(65)%compound_name='<ion+ walls>'
allocate(var(65)%component(1))
var(65)%component=[ 65 ]
var(65)%output=.false.

!equation: <ion- walls> -> var[j,66] -> var(j,66) -> var(66)%funk(nsvar(66,j))%v
var(66)%name='<ion- walls>'
var(66)%multiplier=1.d0
var(66)%units='1'
var(66)%centring='face'
var(66)%type='equation'
var(66)%rank='scalar'
var(66)%region='<walls>'
var(66)%compound_name='<ion- walls>'
allocate(var(66)%component(1))
var(66)%component=[ 66 ]
var(66)%output=.false.

!equation: <ion+ inlet> -> var[j,67] -> var(j,67) -> var(67)%funk(nsvar(67,j))%v
var(67)%name='<ion+ inlet>'
var(67)%multiplier=1.d0
var(67)%units='1'
var(67)%centring='face'
var(67)%type='equation'
var(67)%rank='scalar'
var(67)%region='<inlet>'
var(67)%compound_name='<ion+ inlet>'
allocate(var(67)%component(1))
var(67)%component=[ 67 ]
var(67)%output=.false.

!equation: <ion- inlet> -> var[j,68] -> var(j,68) -> var(68)%funk(nsvar(68,j))%v
var(68)%name='<ion- inlet>'
var(68)%multiplier=1.d0
var(68)%units='1'
var(68)%centring='face'
var(68)%type='equation'
var(68)%rank='scalar'
var(68)%region='<inlet>'
var(68)%compound_name='<ion- inlet>'
allocate(var(68)%component(1))
var(68)%component=[ 68 ]
var(68)%output=.false.

!equation: <I_total equation> -> var[69] -> var(69) -> var(69)%funk(1)%v
var(69)%name='<I_total equation>'
var(69)%multiplier=1.d0
var(69)%units='1'
var(69)%centring='none'
var(69)%type='equation'
var(69)%rank='scalar'
var(69)%region=''
var(69)%compound_name='<I_total equation>'
allocate(var(69)%component(1))
var(69)%component=[ 69 ]
var(69)%output=.false.

!equation: <U poisson equation> -> var[i,70] -> var(i,70) -> var(70)%funk(nsvar(70,i))%v
var(70)%name='<U poisson equation>'
var(70)%multiplier=1.d0
var(70)%units='1'
var(70)%centring='cell'
var(70)%type='equation'
var(70)%rank='scalar'
var(70)%region='<domain>'
var(70)%compound_name='<U poisson equation>'
allocate(var(70)%component(1))
var(70)%component=[ 70 ]
var(70)%output=.false.

!equation: <U symmetry> -> var[j,71] -> var(j,71) -> var(71)%funk(nsvar(71,j))%v
var(71)%name='<U symmetry>'
var(71)%multiplier=1.d0
var(71)%units='1'
var(71)%centring='face'
var(71)%type='equation'
var(71)%rank='scalar'
var(71)%region='<centreline>'
var(71)%compound_name='<U symmetry>'
allocate(var(71)%component(1))
var(71)%component=[ 71 ]
var(71)%output=.false.

!equation: <U walls> -> var[j,72] -> var(j,72) -> var(72)%funk(nsvar(72,j))%v
var(72)%name='<U walls>'
var(72)%multiplier=1.d0
var(72)%units='1'
var(72)%centring='face'
var(72)%type='equation'
var(72)%rank='scalar'
var(72)%region='<walls>'
var(72)%compound_name='<U walls>'
allocate(var(72)%component(1))
var(72)%component=[ 72 ]
var(72)%output=.false.

!equation: <U inlet> -> var[j,73] -> var(j,73) -> var(73)%funk(nsvar(73,j))%v
var(73)%name='<U inlet>'
var(73)%multiplier=1.d0
var(73)%units='1'
var(73)%centring='face'
var(73)%type='equation'
var(73)%rank='scalar'
var(73)%region='<inlet sans centreline>'
var(73)%compound_name='<U inlet>'
allocate(var(73)%component(1))
var(73)%component=[ 73 ]
var(73)%output=.false.

!equation: <U inlet centreline> -> var[j,74] -> var(j,74) -> var(74)%funk(nsvar(74,j))%v
var(74)%name='<U inlet centreline>'
var(74)%multiplier=1.d0
var(74)%units='1'
var(74)%centring='face'
var(74)%type='equation'
var(74)%rank='scalar'
var(74)%region='<inlet centreline>'
var(74)%compound_name='<U inlet centreline>'
allocate(var(74)%component(1))
var(74)%component=[ 74 ]
var(74)%output=.false.

!equation: <U outlet> -> var[j,75] -> var(j,75) -> var(75)%funk(nsvar(75,j))%v
var(75)%name='<U outlet>'
var(75)%multiplier=1.d0
var(75)%units='1'
var(75)%centring='face'
var(75)%type='equation'
var(75)%rank='scalar'
var(75)%region='<outlet>'
var(75)%compound_name='<U outlet>'
allocate(var(75)%component(1))
var(75)%component=[ 75 ]
var(75)%output=.false.

!output: <n_0> -> var[i,76] -> var(i,76) -> var(76)%funk(nsvar(76,i))%v
var(76)%name='<n_0>'
var(76)%multiplier=1.d0
var(76)%units='1'
var(76)%centring='cell'
var(76)%type='output'
var(76)%rank='scalar'
var(76)%region='<all cells>'
var(76)%compound_name='<n_0>'
allocate(var(76)%component(1))
var(76)%component=[ 76 ]
var(76)%output=.false.

!output: <rho_e> -> var[i,77] -> var(i,77) -> var(77)%funk(nsvar(77,i))%v
var(77)%name='<rho_e>'
var(77)%multiplier=1.d0
var(77)%units='1'
var(77)%centring='cell'
var(77)%type='output'
var(77)%rank='scalar'
var(77)%region='<all cells>'
var(77)%compound_name='<rho_e>'
allocate(var(77)%component(1))
var(77)%component=[ 77 ]
var(77)%output=.false.

!output: <n+ error> -> var[i,78] -> var(i,78) -> var(78)%funk(nsvar(78,i))%v
var(78)%name='<n+ error>'
var(78)%multiplier=1.d0
var(78)%units='1'
var(78)%centring='cell'
var(78)%type='output'
var(78)%rank='scalar'
var(78)%region='<all cells>'
var(78)%compound_name='<n+ error>'
allocate(var(78)%component(1))
var(78)%component=[ 78 ]
var(78)%output=.false.

!output: <n- error> -> var[i,79] -> var(i,79) -> var(79)%funk(nsvar(79,i))%v
var(79)%name='<n- error>'
var(79)%multiplier=1.d0
var(79)%units='1'
var(79)%centring='cell'
var(79)%type='output'
var(79)%rank='scalar'
var(79)%region='<all cells>'
var(79)%compound_name='<n- error>'
allocate(var(79)%component(1))
var(79)%component=[ 79 ]
var(79)%output=.false.

!output: <grad rho_e[l=1]> -> var[i,80] -> var(i,80) -> var(80)%funk(nsvar(80,i))%v
var(80)%name='<grad rho_e[l=1]>'
var(80)%multiplier=1.d0
var(80)%units='1'
var(80)%centring='cell'
var(80)%type='output'
var(80)%rank='vector'
var(80)%region='<all cells>'
var(80)%compound_name='<grad rho_e>'
allocate(var(80)%component(3))
var(80)%component=[ 80 , 81 , 82 ]
var(80)%output=.false.

!output: <grad rho_e[l=2]> -> var[i,81] -> var(i,81) -> var(81)%funk(nsvar(81,i))%v
var(81)%name='<grad rho_e[l=2]>'
var(81)%multiplier=1.d0
var(81)%units='1'
var(81)%centring='cell'
var(81)%type='output'
var(81)%rank='vector'
var(81)%region='<all cells>'
var(81)%compound_name='<grad rho_e>'
allocate(var(81)%component(3))
var(81)%component=[ 80 , 81 , 82 ]
var(81)%output=.false.

!output: <grad rho_e[l=3]> -> var[i,82] -> var(i,82) -> var(82)%funk(nsvar(82,i))%v
var(82)%name='<grad rho_e[l=3]>'
var(82)%multiplier=1.d0
var(82)%units='1'
var(82)%centring='cell'
var(82)%type='output'
var(82)%rank='vector'
var(82)%region='<all cells>'
var(82)%compound_name='<grad rho_e>'
allocate(var(82)%component(3))
var(82)%component=[ 80 , 81 , 82 ]
var(82)%output=.false.

!output: <grad rho_e mag> -> var[i,83] -> var(i,83) -> var(83)%funk(nsvar(83,i))%v
var(83)%name='<grad rho_e mag>'
var(83)%multiplier=1.d0
var(83)%units='1'
var(83)%centring='cell'
var(83)%type='output'
var(83)%rank='scalar'
var(83)%region='<all cells>'
var(83)%compound_name='<grad rho_e mag>'
allocate(var(83)%component(1))
var(83)%component=[ 83 ]
var(83)%output=.false.

!output: <grad rho_e av> -> var[84] -> var(84) -> var(84)%funk(1)%v
var(84)%name='<grad rho_e av>'
var(84)%multiplier=1.d0
var(84)%units='1'
var(84)%centring='none'
var(84)%type='output'
var(84)%rank='scalar'
var(84)%region=''
var(84)%compound_name='<grad rho_e av>'
allocate(var(84)%component(1))
var(84)%component=[ 84 ]
var(84)%output=.false.

!output: <mesh rho_e> -> var[i,85] -> var(i,85) -> var(85)%funk(nsvar(85,i))%v
var(85)%name='<mesh rho_e>'
var(85)%multiplier=1.d0
var(85)%units='1'
var(85)%centring='cell'
var(85)%type='output'
var(85)%rank='scalar'
var(85)%region='<all cells>'
var(85)%compound_name='<mesh rho_e>'
allocate(var(85)%component(1))
var(85)%component=[ 85 ]
var(85)%output=.false.

!compound: <Re> of scalar rank
compound(1)%name='<Re>'
compound(1)%units='1'
compound(1)%centring='none'
compound(1)%type='constant'
compound(1)%rank='scalar'
compound(1)%region=''
allocate(compound(1)%component(1))
compound(1)%component=[ 1 ]
compound(1)%output=.false.

!compound: <Sc> of scalar rank
compound(2)%name='<Sc>'
compound(2)%units='1'
compound(2)%centring='none'
compound(2)%type='constant'
compound(2)%rank='scalar'
compound(2)%region=''
allocate(compound(2)%component(1))
compound(2)%component=[ 2 ]
compound(2)%output=.false.

!compound: <B> of scalar rank
compound(3)%name='<B>'
compound(3)%units='1'
compound(3)%centring='none'
compound(3)%type='constant'
compound(3)%rank='scalar'
compound(3)%region=''
allocate(compound(3)%component(1))
compound(3)%component=[ 3 ]
compound(3)%output=.false.

!compound: <K> of scalar rank
compound(4)%name='<K>'
compound(4)%units='1'
compound(4)%centring='none'
compound(4)%type='constant'
compound(4)%rank='scalar'
compound(4)%region=''
allocate(compound(4)%component(1))
compound(4)%component=[ 4 ]
compound(4)%output=.false.

!compound: <S> of scalar rank
compound(5)%name='<S>'
compound(5)%units='1'
compound(5)%centring='none'
compound(5)%type='constant'
compound(5)%rank='scalar'
compound(5)%region=''
allocate(compound(5)%component(1))
compound(5)%component=[ 5 ]
compound(5)%output=.false.

!compound: <I_total> of scalar rank
compound(6)%name='<I_total>'
compound(6)%units='1'
compound(6)%centring='none'
compound(6)%type='constant'
compound(6)%rank='scalar'
compound(6)%region=''
allocate(compound(6)%component(1))
compound(6)%component=[ 6 ]
compound(6)%output=.false.

!compound: <C_{Rhie-Chow}> of scalar rank
compound(7)%name='<C_{Rhie-Chow}>'
compound(7)%units='1'
compound(7)%centring='none'
compound(7)%type='constant'
compound(7)%rank='scalar'
compound(7)%region=''
allocate(compound(7)%component(1))
compound(7)%component=[ 7 ]
compound(7)%output=.false.

!compound: <adv_limiter> of scalar rank
compound(8)%name='<adv_limiter>'
compound(8)%units='1'
compound(8)%centring='none'
compound(8)%type='constant'
compound(8)%rank='scalar'
compound(8)%region=''
allocate(compound(8)%component(1))
compound(8)%component=[ 8 ]
compound(8)%output=.false.

!compound: <ion adv_limiter> of scalar rank
compound(9)%name='<ion adv_limiter>'
compound(9)%units='1'
compound(9)%centring='none'
compound(9)%type='constant'
compound(9)%rank='scalar'
compound(9)%region=''
allocate(compound(9)%component(1))
compound(9)%component=[ 9 ]
compound(9)%output=.false.

!compound: <n_min> of scalar rank
compound(10)%name='<n_min>'
compound(10)%units='1'
compound(10)%centring='none'
compound(10)%type='constant'
compound(10)%rank='scalar'
compound(10)%region=''
allocate(compound(10)%component(1))
compound(10)%component=[ 10 ]
compound(10)%output=.false.

!compound: <u> of vector rank
compound(11)%name='<u>'
compound(11)%units='1'
compound(11)%centring='cell'
compound(11)%type='independent'
compound(11)%rank='vector'
compound(11)%region='<all cells>'
allocate(compound(11)%component(3))
compound(11)%component=[ 11 , 12 , 0 ]
compound(11)%output=.true.

!compound: <p> of scalar rank
compound(12)%name='<p>'
compound(12)%units='1'
compound(12)%centring='cell'
compound(12)%type='independent'
compound(12)%rank='scalar'
compound(12)%region='<all cells>'
allocate(compound(12)%component(1))
compound(12)%component=[ 13 ]
compound(12)%output=.true.

!compound: <p_in> of scalar rank
compound(13)%name='<p_in>'
compound(13)%units='Pa'
compound(13)%centring='none'
compound(13)%type='independent'
compound(13)%rank='scalar'
compound(13)%region=''
allocate(compound(13)%component(1))
compound(13)%component=[ 14 ]
compound(13)%output=.true.

!compound: <n+> of scalar rank
compound(14)%name='<n+>'
compound(14)%units='1'
compound(14)%centring='cell'
compound(14)%type='independent'
compound(14)%rank='scalar'
compound(14)%region='<all cells>'
allocate(compound(14)%component(1))
compound(14)%component=[ 15 ]
compound(14)%output=.true.

!compound: <n-> of scalar rank
compound(15)%name='<n->'
compound(15)%units='1'
compound(15)%centring='cell'
compound(15)%type='independent'
compound(15)%rank='scalar'
compound(15)%region='<all cells>'
allocate(compound(15)%component(1))
compound(15)%component=[ 16 ]
compound(15)%output=.true.

!compound: <dUdx inlet> of scalar rank
compound(16)%name='<dUdx inlet>'
compound(16)%units='1'
compound(16)%centring='none'
compound(16)%type='independent'
compound(16)%rank='scalar'
compound(16)%region=''
allocate(compound(16)%component(1))
compound(16)%component=[ 17 ]
compound(16)%output=.true.

!compound: <U> of scalar rank
compound(17)%name='<U>'
compound(17)%units='1'
compound(17)%centring='cell'
compound(17)%type='independent'
compound(17)%rank='scalar'
compound(17)%region='<all cells>'
allocate(compound(17)%component(1))
compound(17)%component=[ 18 ]
compound(17)%output=.true.

!compound: <tau> of tensor rank
compound(18)%name='<tau>'
compound(18)%units='1'
compound(18)%centring='face'
compound(18)%type='dependent'
compound(18)%rank='tensor'
compound(18)%region='<all faces>'
allocate(compound(18)%component(9))
compound(18)%component=[ 19 , 20 , 0 , 22 , 21 , 0 , 0 , 0 , 0 ]
compound(18)%output=.true.

!compound: <graddivp> of vector rank
compound(19)%name='<graddivp>'
compound(19)%units='1'
compound(19)%centring='cell'
compound(19)%type='dependent'
compound(19)%rank='vector'
compound(19)%region='<all cells>'
allocate(compound(19)%component(3))
compound(19)%component=[ 23 , 24 , 0 ]
compound(19)%output=.true.

!compound: <p_error> of scalar rank
compound(20)%name='<p_error>'
compound(20)%units='1'
compound(20)%centring='face'
compound(20)%type='dependent'
compound(20)%rank='scalar'
compound(20)%region='<all faces>'
allocate(compound(20)%component(1))
compound(20)%component=[ 25 ]
compound(20)%output=.false.

!compound: <u_f_{correction}> of scalar rank
compound(21)%name='<u_f_{correction}>'
compound(21)%units='1'
compound(21)%centring='face'
compound(21)%type='dependent'
compound(21)%rank='scalar'
compound(21)%region='<all faces>'
allocate(compound(21)%component(1))
compound(21)%component=[ 26 ]
compound(21)%output=.true.

!compound: <u_f> of scalar rank
compound(22)%name='<u_f>'
compound(22)%units='1'
compound(22)%centring='face'
compound(22)%type='dependent'
compound(22)%rank='scalar'
compound(22)%region='<all faces>'
allocate(compound(22)%component(1))
compound(22)%component=[ 27 ]
compound(22)%output=.false.

!compound: <J_f> of vector rank
compound(23)%name='<J_f>'
compound(23)%units='1'
compound(23)%centring='face'
compound(23)%type='dependent'
compound(23)%rank='vector'
compound(23)%region='<all faces>'
allocate(compound(23)%component(3))
compound(23)%component=[ 28 , 29 , 0 ]
compound(23)%output=.true.

!compound: <u_av_calc> of scalar rank
compound(24)%name='<u_av_calc>'
compound(24)%units='1'
compound(24)%centring='none'
compound(24)%type='dependent'
compound(24)%rank='scalar'
compound(24)%region=''
allocate(compound(24)%component(1))
compound(24)%component=[ 30 ]
compound(24)%output=.false.

!compound: <n+ lim> of scalar rank
compound(25)%name='<n+ lim>'
compound(25)%units='1'
compound(25)%centring='cell'
compound(25)%type='dependent'
compound(25)%rank='scalar'
compound(25)%region='<all cells>'
allocate(compound(25)%component(1))
compound(25)%component=[ 31 ]
compound(25)%output=.true.

!compound: <n- lim> of scalar rank
compound(26)%name='<n- lim>'
compound(26)%units='1'
compound(26)%centring='cell'
compound(26)%type='dependent'
compound(26)%rank='scalar'
compound(26)%region='<all cells>'
allocate(compound(26)%component(1))
compound(26)%component=[ 32 ]
compound(26)%output=.true.

!compound: <ion+ limiter> of scalar rank
compound(27)%name='<ion+ limiter>'
compound(27)%units='1'
compound(27)%centring='cell'
compound(27)%type='dependent'
compound(27)%rank='scalar'
compound(27)%region='<all cells>'
allocate(compound(27)%component(1))
compound(27)%component=[ 33 ]
compound(27)%output=.false.

!compound: <ion- limiter> of scalar rank
compound(28)%name='<ion- limiter>'
compound(28)%units='1'
compound(28)%centring='cell'
compound(28)%type='dependent'
compound(28)%rank='scalar'
compound(28)%region='<all cells>'
allocate(compound(28)%component(1))
compound(28)%component=[ 34 ]
compound(28)%output=.false.

!compound: <n+_adv_f> of scalar rank
compound(29)%name='<n+_adv_f>'
compound(29)%units='1'
compound(29)%centring='face'
compound(29)%type='dependent'
compound(29)%rank='scalar'
compound(29)%region='<all faces>'
allocate(compound(29)%component(1))
compound(29)%component=[ 35 ]
compound(29)%output=.false.

!compound: <n-_adv_f> of scalar rank
compound(30)%name='<n-_adv_f>'
compound(30)%units='1'
compound(30)%centring='face'
compound(30)%type='dependent'
compound(30)%rank='scalar'
compound(30)%region='<all faces>'
allocate(compound(30)%component(1))
compound(30)%component=[ 36 ]
compound(30)%output=.false.

!compound: <J+_f> of scalar rank
compound(31)%name='<J+_f>'
compound(31)%units='1'
compound(31)%centring='face'
compound(31)%type='dependent'
compound(31)%rank='scalar'
compound(31)%region='<all faces>'
allocate(compound(31)%component(1))
compound(31)%component=[ 37 ]
compound(31)%output=.false.

!compound: <J-_f> of scalar rank
compound(32)%name='<J-_f>'
compound(32)%units='1'
compound(32)%centring='face'
compound(32)%type='dependent'
compound(32)%rank='scalar'
compound(32)%region='<all faces>'
allocate(compound(32)%component(1))
compound(32)%component=[ 38 ]
compound(32)%output=.false.

!compound: <I+> of scalar rank
compound(33)%name='<I+>'
compound(33)%units='1'
compound(33)%centring='none'
compound(33)%type='dependent'
compound(33)%rank='scalar'
compound(33)%region=''
allocate(compound(33)%component(1))
compound(33)%component=[ 39 ]
compound(33)%output=.false.

!compound: <I-> of scalar rank
compound(34)%name='<I->'
compound(34)%units='1'
compound(34)%centring='none'
compound(34)%type='dependent'
compound(34)%rank='scalar'
compound(34)%region=''
allocate(compound(34)%component(1))
compound(34)%component=[ 40 ]
compound(34)%output=.false.

!compound: <I_total_calc> of scalar rank
compound(35)%name='<I_total_calc>'
compound(35)%units='1'
compound(35)%centring='none'
compound(35)%type='dependent'
compound(35)%rank='scalar'
compound(35)%region=''
allocate(compound(35)%component(1))
compound(35)%component=[ 41 ]
compound(35)%output=.false.

!compound: <dUdx outlet> of scalar rank
compound(36)%name='<dUdx outlet>'
compound(36)%units='1'
compound(36)%centring='none'
compound(36)%type='dependent'
compound(36)%rank='scalar'
compound(36)%region=''
allocate(compound(36)%component(1))
compound(36)%component=[ 42 ]
compound(36)%output=.false.

!compound: <continuity> of scalar rank
compound(37)%name='<continuity>'
compound(37)%units='1'
compound(37)%centring='cell'
compound(37)%type='equation'
compound(37)%rank='scalar'
compound(37)%region='<domain>'
allocate(compound(37)%component(1))
compound(37)%component=[ 43 ]
compound(37)%output=.false.

!compound: <momentum> of vector rank
compound(38)%name='<momentum>'
compound(38)%units='1'
compound(38)%centring='cell'
compound(38)%type='equation'
compound(38)%rank='vector'
compound(38)%region='<domain>'
allocate(compound(38)%component(3))
compound(38)%component=[ 44 , 45 , 0 ]
compound(38)%output=.false.

!compound: <wall noflux> of scalar rank
compound(39)%name='<wall noflux>'
compound(39)%units='1'
compound(39)%centring='face'
compound(39)%type='equation'
compound(39)%rank='scalar'
compound(39)%region='<walls>'
allocate(compound(39)%component(1))
compound(39)%component=[ 46 ]
compound(39)%output=.false.

!compound: <wall noslip> of scalar rank
compound(40)%name='<wall noslip>'
compound(40)%units='1'
compound(40)%centring='face'
compound(40)%type='equation'
compound(40)%rank='scalar'
compound(40)%region='<walls>'
allocate(compound(40)%component(1))
compound(40)%component=[ 47 ]
compound(40)%output=.false.

!compound: <wall p extrapolation> of scalar rank
compound(41)%name='<wall p extrapolation>'
compound(41)%units='1'
compound(41)%centring='face'
compound(41)%type='equation'
compound(41)%rank='scalar'
compound(41)%region='<walls>'
allocate(compound(41)%component(1))
compound(41)%component=[ 48 ]
compound(41)%output=.false.

!compound: <outlet fully developed> of scalar rank
compound(42)%name='<outlet fully developed>'
compound(42)%units='1'
compound(42)%centring='face'
compound(42)%type='equation'
compound(42)%rank='scalar'
compound(42)%region='<outlet>'
allocate(compound(42)%component(1))
compound(42)%component=[ 49 ]
compound(42)%output=.false.

!compound: <outlet noslip> of scalar rank
compound(43)%name='<outlet noslip>'
compound(43)%units='1'
compound(43)%centring='face'
compound(43)%type='equation'
compound(43)%rank='scalar'
compound(43)%region='<outlet>'
allocate(compound(43)%component(1))
compound(43)%component=[ 50 ]
compound(43)%output=.false.

!compound: <outlet p> of scalar rank
compound(44)%name='<outlet p>'
compound(44)%units='1'
compound(44)%centring='face'
compound(44)%type='equation'
compound(44)%rank='scalar'
compound(44)%region='<outlet>'
allocate(compound(44)%component(1))
compound(44)%component=[ 51 ]
compound(44)%output=.false.

!compound: <inlet fully developed> of scalar rank
compound(45)%name='<inlet fully developed>'
compound(45)%units='1'
compound(45)%centring='face'
compound(45)%type='equation'
compound(45)%rank='scalar'
compound(45)%region='<inlet>'
allocate(compound(45)%component(1))
compound(45)%component=[ 52 ]
compound(45)%output=.false.

!compound: <inlet noslip> of scalar rank
compound(46)%name='<inlet noslip>'
compound(46)%units='1'
compound(46)%centring='face'
compound(46)%type='equation'
compound(46)%rank='scalar'
compound(46)%region='<inlet>'
allocate(compound(46)%component(1))
compound(46)%component=[ 53 ]
compound(46)%output=.false.

!compound: <p_in for flowrate> of scalar rank
compound(47)%name='<p_in for flowrate>'
compound(47)%units='1'
compound(47)%centring='none'
compound(47)%type='equation'
compound(47)%rank='scalar'
compound(47)%region=''
allocate(compound(47)%component(1))
compound(47)%component=[ 54 ]
compound(47)%output=.false.

!compound: <inlet flowrate> of scalar rank
compound(48)%name='<inlet flowrate>'
compound(48)%units='1'
compound(48)%centring='face'
compound(48)%type='equation'
compound(48)%rank='scalar'
compound(48)%region='<inlet>'
allocate(compound(48)%component(1))
compound(48)%component=[ 55 ]
compound(48)%output=.false.

!compound: <velocity symmetry > of vector rank
compound(49)%name='<velocity symmetry >'
compound(49)%units='1'
compound(49)%centring='face'
compound(49)%type='equation'
compound(49)%rank='vector'
compound(49)%region='<centreline>'
allocate(compound(49)%component(3))
compound(49)%component=[ 56 , 57 , 0 ]
compound(49)%output=.false.

!compound: <pressure symmetry> of scalar rank
compound(50)%name='<pressure symmetry>'
compound(50)%units='1'
compound(50)%centring='face'
compound(50)%type='equation'
compound(50)%rank='scalar'
compound(50)%region='<centreline>'
allocate(compound(50)%component(1))
compound(50)%component=[ 58 ]
compound(50)%output=.false.

!compound: <ion+ continuity> of scalar rank
compound(51)%name='<ion+ continuity>'
compound(51)%units='1'
compound(51)%centring='cell'
compound(51)%type='equation'
compound(51)%rank='scalar'
compound(51)%region='<domain>'
allocate(compound(51)%component(1))
compound(51)%component=[ 59 ]
compound(51)%output=.false.

!compound: <ion- continuity> of scalar rank
compound(52)%name='<ion- continuity>'
compound(52)%units='1'
compound(52)%centring='cell'
compound(52)%type='equation'
compound(52)%rank='scalar'
compound(52)%region='<domain>'
allocate(compound(52)%component(1))
compound(52)%component=[ 60 ]
compound(52)%output=.false.

!compound: <ion+ symmetry> of scalar rank
compound(53)%name='<ion+ symmetry>'
compound(53)%units='1'
compound(53)%centring='face'
compound(53)%type='equation'
compound(53)%rank='scalar'
compound(53)%region='<centreline>'
allocate(compound(53)%component(1))
compound(53)%component=[ 61 ]
compound(53)%output=.false.

!compound: <ion- symmetry> of scalar rank
compound(54)%name='<ion- symmetry>'
compound(54)%units='1'
compound(54)%centring='face'
compound(54)%type='equation'
compound(54)%rank='scalar'
compound(54)%region='<centreline>'
allocate(compound(54)%component(1))
compound(54)%component=[ 62 ]
compound(54)%output=.false.

!compound: <ion+ outlet> of scalar rank
compound(55)%name='<ion+ outlet>'
compound(55)%units='1'
compound(55)%centring='face'
compound(55)%type='equation'
compound(55)%rank='scalar'
compound(55)%region='<outlet>'
allocate(compound(55)%component(1))
compound(55)%component=[ 63 ]
compound(55)%output=.false.

!compound: <ion- outlet> of scalar rank
compound(56)%name='<ion- outlet>'
compound(56)%units='1'
compound(56)%centring='face'
compound(56)%type='equation'
compound(56)%rank='scalar'
compound(56)%region='<outlet>'
allocate(compound(56)%component(1))
compound(56)%component=[ 64 ]
compound(56)%output=.false.

!compound: <ion+ walls> of scalar rank
compound(57)%name='<ion+ walls>'
compound(57)%units='1'
compound(57)%centring='face'
compound(57)%type='equation'
compound(57)%rank='scalar'
compound(57)%region='<walls>'
allocate(compound(57)%component(1))
compound(57)%component=[ 65 ]
compound(57)%output=.false.

!compound: <ion- walls> of scalar rank
compound(58)%name='<ion- walls>'
compound(58)%units='1'
compound(58)%centring='face'
compound(58)%type='equation'
compound(58)%rank='scalar'
compound(58)%region='<walls>'
allocate(compound(58)%component(1))
compound(58)%component=[ 66 ]
compound(58)%output=.false.

!compound: <ion+ inlet> of scalar rank
compound(59)%name='<ion+ inlet>'
compound(59)%units='1'
compound(59)%centring='face'
compound(59)%type='equation'
compound(59)%rank='scalar'
compound(59)%region='<inlet>'
allocate(compound(59)%component(1))
compound(59)%component=[ 67 ]
compound(59)%output=.false.

!compound: <ion- inlet> of scalar rank
compound(60)%name='<ion- inlet>'
compound(60)%units='1'
compound(60)%centring='face'
compound(60)%type='equation'
compound(60)%rank='scalar'
compound(60)%region='<inlet>'
allocate(compound(60)%component(1))
compound(60)%component=[ 68 ]
compound(60)%output=.false.

!compound: <I_total equation> of scalar rank
compound(61)%name='<I_total equation>'
compound(61)%units='1'
compound(61)%centring='none'
compound(61)%type='equation'
compound(61)%rank='scalar'
compound(61)%region=''
allocate(compound(61)%component(1))
compound(61)%component=[ 69 ]
compound(61)%output=.false.

!compound: <U poisson equation> of scalar rank
compound(62)%name='<U poisson equation>'
compound(62)%units='1'
compound(62)%centring='cell'
compound(62)%type='equation'
compound(62)%rank='scalar'
compound(62)%region='<domain>'
allocate(compound(62)%component(1))
compound(62)%component=[ 70 ]
compound(62)%output=.false.

!compound: <U symmetry> of scalar rank
compound(63)%name='<U symmetry>'
compound(63)%units='1'
compound(63)%centring='face'
compound(63)%type='equation'
compound(63)%rank='scalar'
compound(63)%region='<centreline>'
allocate(compound(63)%component(1))
compound(63)%component=[ 71 ]
compound(63)%output=.false.

!compound: <U walls> of scalar rank
compound(64)%name='<U walls>'
compound(64)%units='1'
compound(64)%centring='face'
compound(64)%type='equation'
compound(64)%rank='scalar'
compound(64)%region='<walls>'
allocate(compound(64)%component(1))
compound(64)%component=[ 72 ]
compound(64)%output=.false.

!compound: <U inlet> of scalar rank
compound(65)%name='<U inlet>'
compound(65)%units='1'
compound(65)%centring='face'
compound(65)%type='equation'
compound(65)%rank='scalar'
compound(65)%region='<inlet sans centreline>'
allocate(compound(65)%component(1))
compound(65)%component=[ 73 ]
compound(65)%output=.false.

!compound: <U inlet centreline> of scalar rank
compound(66)%name='<U inlet centreline>'
compound(66)%units='1'
compound(66)%centring='face'
compound(66)%type='equation'
compound(66)%rank='scalar'
compound(66)%region='<inlet centreline>'
allocate(compound(66)%component(1))
compound(66)%component=[ 74 ]
compound(66)%output=.false.

!compound: <U outlet> of scalar rank
compound(67)%name='<U outlet>'
compound(67)%units='1'
compound(67)%centring='face'
compound(67)%type='equation'
compound(67)%rank='scalar'
compound(67)%region='<outlet>'
allocate(compound(67)%component(1))
compound(67)%component=[ 75 ]
compound(67)%output=.false.

!compound: <n_0> of scalar rank
compound(68)%name='<n_0>'
compound(68)%units='1'
compound(68)%centring='cell'
compound(68)%type='output'
compound(68)%rank='scalar'
compound(68)%region='<all cells>'
allocate(compound(68)%component(1))
compound(68)%component=[ 76 ]
compound(68)%output=.true.

!compound: <rho_e> of scalar rank
compound(69)%name='<rho_e>'
compound(69)%units='1'
compound(69)%centring='cell'
compound(69)%type='output'
compound(69)%rank='scalar'
compound(69)%region='<all cells>'
allocate(compound(69)%component(1))
compound(69)%component=[ 77 ]
compound(69)%output=.true.

!compound: <n+ error> of scalar rank
compound(70)%name='<n+ error>'
compound(70)%units='1'
compound(70)%centring='cell'
compound(70)%type='output'
compound(70)%rank='scalar'
compound(70)%region='<all cells>'
allocate(compound(70)%component(1))
compound(70)%component=[ 78 ]
compound(70)%output=.true.

!compound: <n- error> of scalar rank
compound(71)%name='<n- error>'
compound(71)%units='1'
compound(71)%centring='cell'
compound(71)%type='output'
compound(71)%rank='scalar'
compound(71)%region='<all cells>'
allocate(compound(71)%component(1))
compound(71)%component=[ 79 ]
compound(71)%output=.true.

!compound: <grad rho_e> of vector rank
compound(72)%name='<grad rho_e>'
compound(72)%units='1'
compound(72)%centring='cell'
compound(72)%type='output'
compound(72)%rank='vector'
compound(72)%region='<all cells>'
allocate(compound(72)%component(3))
compound(72)%component=[ 80 , 81 , 82 ]
compound(72)%output=.true.

!compound: <grad rho_e mag> of scalar rank
compound(73)%name='<grad rho_e mag>'
compound(73)%units='1'
compound(73)%centring='cell'
compound(73)%type='output'
compound(73)%rank='scalar'
compound(73)%region='<all cells>'
allocate(compound(73)%component(1))
compound(73)%component=[ 83 ]
compound(73)%output=.true.

!compound: <grad rho_e av> of scalar rank
compound(74)%name='<grad rho_e av>'
compound(74)%units='1'
compound(74)%centring='none'
compound(74)%type='output'
compound(74)%rank='scalar'
compound(74)%region=''
allocate(compound(74)%component(1))
compound(74)%component=[ 84 ]
compound(74)%output=.true.

!compound: <mesh rho_e> of scalar rank
compound(75)%name='<mesh rho_e>'
compound(75)%units='1'
compound(75)%centring='cell'
compound(75)%type='output'
compound(75)%rank='scalar'
compound(75)%region='<all cells>'
allocate(compound(75)%component(1))
compound(75)%component=[ 85 ]
compound(75)%output=.true.

constants_file = "constants.in" ! filename that was used by setup_equations


! setup someloop which is also used locally within update subroutines
allocate(someloop(141))


if (debug) write(*,'(a/80(1h-))') 'subroutine allocate_meta_arrays'

end subroutine allocate_meta_arrays

!----------------------------------------------------------------------------

subroutine update

! here we update all the dependents and equations

use general_module
integer :: nvar, m, ns, i, j
double precision :: deriv
character(len=1000) :: formatline
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine update'

if (debug) write(*,'(40(1h+)/a)') 'dependent updates'

do nvar = 1, allocatable_size(var_list(var_list_number(centring="all",type="dependent"))%list)
  m = var_list(var_list_number(centring="all",type="dependent"))%list(nvar)

  i = 0
  j = 0

  if (debug) write(*,*) 'updating var dependent: m = ',m,': name = ',trim(var(m)%name),': centring = ',var(m)%centring

! equations
  if (m == 19) then
! dependent <tau[l=1,1]>
! <p> - 2.d0*facegrad[l=1](<u[l=1]>)/<Re>
! someloop[2]-2.0*someloop[1]/var[1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(1,i,j)
      call update_someloop(2,i,j)
      
      var(19)%funk(ns)%v = var(19)%funk(ns)%v + (someloop(2)%v-2.0*someloop(1)%v/var(1)%funk(1)%v)
      
      deriv = -2.0/var(1)%funk(1)%v
      call add_to_dv(var(19)%funk(ns),deriv,someloop(1))
      
      deriv = 1
      call add_to_dv(var(19)%funk(ns),deriv,someloop(2))
      
    end do
    
  else if (m == 20) then
! dependent <tau[l=1,2]>
! - (facegrad[l=2](<u[l=1]>)+facegrad[l=1](<u[l=2]>))/<Re>
! (-someloop[4]-someloop[3])/var[1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(3,i,j)
      call update_someloop(4,i,j)
      
      var(20)%funk(ns)%v = var(20)%funk(ns)%v + ((-someloop(4)%v-someloop(3)%v)/var(1)%funk(1)%v)
      
      deriv = -1/var(1)%funk(1)%v
      call add_to_dv(var(20)%funk(ns),deriv,someloop(3))
      
      deriv = -1/var(1)%funk(1)%v
      call add_to_dv(var(20)%funk(ns),deriv,someloop(4))
      
    end do
    
  else if (m == 21) then
! dependent <tau[l=2,2]>
! <p> - 2.d0*facegrad[l=2](<u[l=2]>)/<Re>
! someloop[6]-2.0*someloop[5]/var[1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(5,i,j)
      call update_someloop(6,i,j)
      
      var(21)%funk(ns)%v = var(21)%funk(ns)%v + (someloop(6)%v-2.0*someloop(5)%v/var(1)%funk(1)%v)
      
      deriv = -2.0/var(1)%funk(1)%v
      call add_to_dv(var(21)%funk(ns),deriv,someloop(5))
      
      deriv = 1
      call add_to_dv(var(21)%funk(ns),deriv,someloop(6))
      
    end do
    
  else if (m == 22) then
! dependent <tau[l=2,1]>
! <tau[l=1,2]>
! var[j,20]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(22)%funk(ns)%v = var(22)%funk(ns)%v + (var(20)%funk(nsvar(20,j))%v)
      
      deriv = 1
      call add_to_dv(var(22)%funk(ns),deriv,var(20)%funk(nsvar(20,j)))
      
    end do
    
  else if (m == 23) then
! dependent <graddivp[l=1]>
! celldivgrad[l=1](<p>)
! someloop[7]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(7,i,j)
      
      var(23)%funk(ns)%v = var(23)%funk(ns)%v + (someloop(7)%v)
      
      deriv = 1
      call add_to_dv(var(23)%funk(ns),deriv,someloop(7))
      
    end do
    
  else if (m == 24) then
! dependent <graddivp[l=2]>
! celldivgrad[l=2](<p>)
! someloop[8]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(8,i,j)
      
      var(24)%funk(ns)%v = var(24)%funk(ns)%v + (someloop(8)%v)
      
      deriv = 1
      call add_to_dv(var(24)%funk(ns),deriv,someloop(8))
      
    end do
    
  else if (m == 25) then
! dependent <p_error>
! facegrad(<p>) - dot(<graddivp[l=:]>,<facenorm[l=:]>)
! -someloop[11]*facenorm[j,2]-someloop[10]*facenorm[j,1]+someloop[9]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(9,i,j)
      call update_someloop(10,i,j)
      call update_someloop(11,i,j)
      
      var(25)%funk(ns)%v = var(25)%funk(ns)%v + (-someloop(11)%v*face(j)%norm(2,1)-someloop(10)%v*face(j)&
        &%norm(1,1)+someloop(9)%v)
      
      deriv = 1
      call add_to_dv(var(25)%funk(ns),deriv,someloop(9))
      
      deriv = -face(j)%norm(1,1)
      call add_to_dv(var(25)%funk(ns),deriv,someloop(10))
      
      deriv = -face(j)%norm(2,1)
      call add_to_dv(var(25)%funk(ns),deriv,someloop(11))
      
    end do
    
  else if (m == 26) then
! dependent <u_f_{correction}>
! -<C_{Rhie-Chow}>*facedelta(<domain faces>)*facemin(<facedx>^2*<Re>, sqrt(<facedx>/(facemax(abs(<p_error>),1.d-6))) )*<p_error>
! -var[7]*someloop[13]*var[j,25]*region_delta(j,"face","<domain faces>")
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(13,i,j)
      
      var(26)%funk(ns)%v = var(26)%funk(ns)%v + (-var(7)%funk(1)%v*someloop(13)%v*var(25)%funk(nsvar(25,j&
        &))%v*region_delta(j,"face","<domain faces>"))
      
      deriv = -var(7)%funk(1)%v*someloop(13)%v*region_delta(j,"face","<domain faces>")
      call add_to_dv(var(26)%funk(ns),deriv,var(25)%funk(nsvar(25,j)))
      
      deriv = -var(7)%funk(1)%v*var(25)%funk(nsvar(25,j))%v*region_delta(j,"face","<domain faces>")
      call add_to_dv(var(26)%funk(ns),deriv,someloop(13))
      
    end do
    
  else if (m == 27) then
! dependent <u_f>
! dot(<u[l=:]>,<facenorm[l=:]>) + <u_f_{correction}>
! var[j,26]+someloop[15]*facenorm[j,2]+someloop[14]*facenorm[j,1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(14,i,j)
      call update_someloop(15,i,j)
      
      var(27)%funk(ns)%v = var(27)%funk(ns)%v + (var(26)%funk(nsvar(26,j))%v+someloop(15)%v*face(j)%norm(&
        &2,1)+someloop(14)%v*face(j)%norm(1,1))
      
      deriv = 1
      call add_to_dv(var(27)%funk(ns),deriv,var(26)%funk(nsvar(26,j)))
      
      deriv = face(j)%norm(1,1)
      call add_to_dv(var(27)%funk(ns),deriv,someloop(14))
      
      deriv = face(j)%norm(2,1)
      call add_to_dv(var(27)%funk(ns),deriv,someloop(15))
      
    end do
    
  else if (m == 28) then
! dependent <J_f[l=1]>
! dot(<facenorm[l=:]>,<tau[l=:,1]>)+faceave[advection](<u[l=1]>,<u_f>,<adv_limiter>)*<u_f>
! someloop[16]*var[j,27]+facenorm[j,2]*var[j,22]+facenorm[j,1]*var[j,19]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(16,i,j)
      
      var(28)%funk(ns)%v = var(28)%funk(ns)%v + (someloop(16)%v*var(27)%funk(nsvar(27,j))%v+face(j)%norm(&
        &2,1)*var(22)%funk(nsvar(22,j))%v+face(j)%norm(1,1)*var(19)%funk(nsvar(19,j))%v)
      
      deriv = face(j)%norm(1,1)
      call add_to_dv(var(28)%funk(ns),deriv,var(19)%funk(nsvar(19,j)))
      
      deriv = face(j)%norm(2,1)
      call add_to_dv(var(28)%funk(ns),deriv,var(22)%funk(nsvar(22,j)))
      
      deriv = someloop(16)%v
      call add_to_dv(var(28)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
      deriv = var(27)%funk(nsvar(27,j))%v
      call add_to_dv(var(28)%funk(ns),deriv,someloop(16))
      
    end do
    
  else if (m == 29) then
! dependent <J_f[l=2]>
! dot(<facenorm[l=:]>,<tau[l=:,2]>)+faceave[advection](<u[l=2]>,<u_f>,<adv_limiter>)*<u_f>
! someloop[17]*var[j,27]+facenorm[j,2]*var[j,21]+facenorm[j,1]*var[j,20]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(17,i,j)
      
      var(29)%funk(ns)%v = var(29)%funk(ns)%v + (someloop(17)%v*var(27)%funk(nsvar(27,j))%v+face(j)%norm(&
        &2,1)*var(21)%funk(nsvar(21,j))%v+face(j)%norm(1,1)*var(20)%funk(nsvar(20,j))%v)
      
      deriv = face(j)%norm(1,1)
      call add_to_dv(var(29)%funk(ns),deriv,var(20)%funk(nsvar(20,j)))
      
      deriv = face(j)%norm(2,1)
      call add_to_dv(var(29)%funk(ns),deriv,var(21)%funk(nsvar(21,j)))
      
      deriv = someloop(17)%v
      call add_to_dv(var(29)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
      deriv = var(27)%funk(nsvar(27,j))%v
      call add_to_dv(var(29)%funk(ns),deriv,someloop(17))
      
    end do
    
  else if (m == 30) then
! dependent <u_av_calc>
! facesum(-<u_f>*<facearea>,<inlet>)/facesum(<facearea>,<inlet>)
! someloop[18]/someloop[19]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      call update_someloop(18,i,j)
      call update_someloop(19,i,j)
      
      var(30)%funk(ns)%v = var(30)%funk(ns)%v + (someloop(18)%v/someloop(19)%v)
      
      deriv = 1/someloop(19)%v
      call add_to_dv(var(30)%funk(ns),deriv,someloop(18))
      
      deriv = -someloop(18)%v/someloop(19)%v**2
      call add_to_dv(var(30)%funk(ns),deriv,someloop(19))
      
    end do
    
  else if (m == 31) then
! dependent <n+ lim>
! cellmax(<n+>,<n_min>)
! someloop[20]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(20,i,j)
      
      var(31)%funk(ns)%v = var(31)%funk(ns)%v + (someloop(20)%v)
      
      deriv = 1
      call add_to_dv(var(31)%funk(ns),deriv,someloop(20))
      
    end do
    
  else if (m == 32) then
! dependent <n- lim>
! cellmax(<n->,<n_min>)
! someloop[21]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(21,i,j)
      
      var(32)%funk(ns)%v = var(32)%funk(ns)%v + (someloop(21)%v)
      
      deriv = 1
      call add_to_dv(var(32)%funk(ns),deriv,someloop(21))
      
    end do
    
  else if (m == 33) then
! dependent <ion+ limiter>
! celllimiter[lower,linear](<n+>,0.d0)
! someloop[22]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(22,i,j)
      
      var(33)%funk(ns)%v = var(33)%funk(ns)%v + (someloop(22)%v)
      
      deriv = 1
      call add_to_dv(var(33)%funk(ns),deriv,someloop(22))
      
    end do
    
  else if (m == 34) then
! dependent <ion- limiter>
! celllimiter[lower,linear](<n->,0.d0)
! someloop[23]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(23,i,j)
      
      var(34)%funk(ns)%v = var(34)%funk(ns)%v + (someloop(23)%v)
      
      deriv = 1
      call add_to_dv(var(34)%funk(ns),deriv,someloop(23))
      
    end do
    
  else if (m == 35) then
! dependent <n+_adv_f>
! facemax(faceave[advection](<n+>,<u_f>,<ion+ limiter>*<ion adv_limiter>),<n_min>)
! someloop[24]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(24,i,j)
      
      var(35)%funk(ns)%v = var(35)%funk(ns)%v + (someloop(24)%v)
      
      deriv = 1
      call add_to_dv(var(35)%funk(ns),deriv,someloop(24))
      
    end do
    
  else if (m == 36) then
! dependent <n-_adv_f>
! facemax(faceave[advection](<n->,<u_f>,<ion- limiter>*<ion adv_limiter>),<n_min>)
! someloop[25]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(25,i,j)
      
      var(36)%funk(ns)%v = var(36)%funk(ns)%v + (someloop(25)%v)
      
      deriv = 1
      call add_to_dv(var(36)%funk(ns),deriv,someloop(25))
      
    end do
    
  else if (m == 37) then
! dependent <J+_f>
! <n+_adv_f>*<u_f>-(facegrad(<n+>)+<n+ lim>*facegrad(<U>))/(<Re>*<Sc>)
! var[j,27]*var[j,35]-(someloop[27]*someloop[28]+someloop[26])/(var[1]*var[2])
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(26,i,j)
      call update_someloop(27,i,j)
      call update_someloop(28,i,j)
      
      var(37)%funk(ns)%v = var(37)%funk(ns)%v + (var(27)%funk(nsvar(27,j))%v*var(35)%funk(nsvar(35,j))%v-&
        &(someloop(27)%v*someloop(28)%v+someloop(26)%v)/(var(1)%funk(1)%v*var(2)%funk(1)%v))
      
      deriv = var(35)%funk(nsvar(35,j))%v
      call add_to_dv(var(37)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
      deriv = var(27)%funk(nsvar(27,j))%v
      call add_to_dv(var(37)%funk(ns),deriv,var(35)%funk(nsvar(35,j)))
      
      deriv = -1/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(37)%funk(ns),deriv,someloop(26))
      
      deriv = -someloop(28)%v/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(37)%funk(ns),deriv,someloop(27))
      
      deriv = -someloop(27)%v/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(37)%funk(ns),deriv,someloop(28))
      
    end do
    
  else if (m == 38) then
! dependent <J-_f>
! <n-_adv_f>*<u_f>-(facegrad(<n->)-<n- lim>*facegrad(<U>))/(<Re>*<Sc>)
! var[j,27]*var[j,36]-(someloop[29]-someloop[30]*someloop[31])/(var[1]*var[2])
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(29,i,j)
      call update_someloop(30,i,j)
      call update_someloop(31,i,j)
      
      var(38)%funk(ns)%v = var(38)%funk(ns)%v + (var(27)%funk(nsvar(27,j))%v*var(36)%funk(nsvar(36,j))%v-&
        &(someloop(29)%v-someloop(30)%v*someloop(31)%v)/(var(1)%funk(1)%v*var(2)%funk(1)%v))
      
      deriv = var(36)%funk(nsvar(36,j))%v
      call add_to_dv(var(38)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
      deriv = var(27)%funk(nsvar(27,j))%v
      call add_to_dv(var(38)%funk(ns),deriv,var(36)%funk(nsvar(36,j)))
      
      deriv = -1/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(38)%funk(ns),deriv,someloop(29))
      
      deriv = someloop(31)%v/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(38)%funk(ns),deriv,someloop(30))
      
      deriv = someloop(30)%v/(var(1)%funk(1)%v*var(2)%funk(1)%v)
      call add_to_dv(var(38)%funk(ns),deriv,someloop(31))
      
    end do
    
  else if (m == 39) then
! dependent <I+>
! facesum(<J+_f>*<facearea>,<inlet>)
! someloop[32]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      call update_someloop(32,i,j)
      
      var(39)%funk(ns)%v = var(39)%funk(ns)%v + (someloop(32)%v)
      
      deriv = 1
      call add_to_dv(var(39)%funk(ns),deriv,someloop(32))
      
    end do
    
  else if (m == 40) then
! dependent <I->
! facesum(-<J-_f>*<facearea>,<inlet>)
! someloop[33]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      call update_someloop(33,i,j)
      
      var(40)%funk(ns)%v = var(40)%funk(ns)%v + (someloop(33)%v)
      
      deriv = 1
      call add_to_dv(var(40)%funk(ns),deriv,someloop(33))
      
    end do
    
  else if (m == 41) then
! dependent <I_total_calc>
! <I+>+<I->
! var[40]+var[39]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      
      var(41)%funk(ns)%v = var(41)%funk(ns)%v + (var(40)%funk(1)%v+var(39)%funk(1)%v)
      
      deriv = 1
      call add_to_dv(var(41)%funk(ns),deriv,var(39)%funk(1))
      
      deriv = 1
      call add_to_dv(var(41)%funk(ns),deriv,var(40)%funk(1))
      
    end do
    
  else if (m == 42) then
! dependent <dUdx outlet>
! (-facesum(<S>*<facearea>,<walls>)+facesum(<dUdx inlet>*<facearea>,<inlet>)-<K>**2*cellsum((<n+>-<n->)*<cellvol>,<domain>)/2.d0)/facesum(<facearea>,<outlet>)
! (-0.5*var[4]^2*someloop[36]+someloop[35]-someloop[34])/someloop[37]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      call update_someloop(34,i,j)
      call update_someloop(35,i,j)
      call update_someloop(36,i,j)
      call update_someloop(37,i,j)
      
      var(42)%funk(ns)%v = var(42)%funk(ns)%v + ((-0.5*var(4)%funk(1)%v**2*someloop(36)%v+someloop(35)%v-&
        &someloop(34)%v)/someloop(37)%v)
      
      deriv = -1/someloop(37)%v
      call add_to_dv(var(42)%funk(ns),deriv,someloop(34))
      
      deriv = 1/someloop(37)%v
      call add_to_dv(var(42)%funk(ns),deriv,someloop(35))
      
      deriv = -0.5*var(4)%funk(1)%v**2/someloop(37)%v
      call add_to_dv(var(42)%funk(ns),deriv,someloop(36))
      
      deriv = -(-0.5*var(4)%funk(1)%v**2*someloop(36)%v+someloop(35)%v-someloop(34)%v)/someloop(37)%v**2
      call add_to_dv(var(42)%funk(ns),deriv,someloop(37))
      
    end do
    
    
  else
    write(*,*) "ERROR: the index ",m," was not found when updating dependent"
    stop
  end if


  if (debug) then
    formatline = '(a,'//trim(indexformat)//',a,i3,a,a)'
    do ns = 1, ubound(var(m)%funk,1)
      write(*,fmt=formatline) '(ns,m) = (',ns,',',m,'): var = ',trim(print_funk(var(m)%funk(ns)))
    end do
  end if

end do

if (debug) write(*,'(a/40(1h-))') 'dependent updates'

!------------------------------------------------------------------

if (debug) write(*,'(40(1h+)/a)') 'equation updates'

do nvar = 1, allocatable_size(var_list(var_list_number(centring="all",type="equation"))%list)
  m = var_list(var_list_number(centring="all",type="equation"))%list(nvar)

  i = 0
  j = 0

  if (debug) write(*,*) 'updating var equation: m = ',m,': name = ',trim(var(m)%name),': centring = ',var(m)%centring

! equations
  if (m == 43) then
! equation <continuity>
! celldiv(<u_f>)
! someloop[38]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(38,i,j)
      
      var(43)%funk(ns)%v = var(43)%funk(ns)%v + (someloop(38)%v)
      
      deriv = 1
      call add_to_dv(var(43)%funk(ns),deriv,someloop(38))
      
    end do
    
  else if (m == 44) then
! equation <momentum[l=1]>
! celldiv(<J_f[l=1]>)+(<B>*<K>**2/<Re>**2)*(<n+ lim>-<n- lim>)*celldivgrad[l=1](<U>)
! var[3]*var[4]^2*someloop[40]*(var[i,31]-var[i,32])/var[1]^2+someloop[39]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(39,i,j)
      call update_someloop(40,i,j)
      
      var(44)%funk(ns)%v = var(44)%funk(ns)%v + (var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(40)%v*(var&
        &(31)%funk(nsvar(31,i))%v-var(32)%funk(nsvar(32,i))%v)/var(1)%funk(1)%v**2+someloop(39)%v)
      
      deriv = var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(40)%v/var(1)%funk(1)%v**2
      call add_to_dv(var(44)%funk(ns),deriv,var(31)%funk(nsvar(31,i)))
      
      deriv = -var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(40)%v/var(1)%funk(1)%v**2
      call add_to_dv(var(44)%funk(ns),deriv,var(32)%funk(nsvar(32,i)))
      
      deriv = 1
      call add_to_dv(var(44)%funk(ns),deriv,someloop(39))
      
      deriv = var(3)%funk(1)%v*var(4)%funk(1)%v**2*(var(31)%funk(nsvar(31,i))%v-var(32)%funk(nsvar(32,i))&
        &%v)/var(1)%funk(1)%v**2
      call add_to_dv(var(44)%funk(ns),deriv,someloop(40))
      
    end do
    
  else if (m == 45) then
! equation <momentum[l=2]>
! celldiv(<J_f[l=2]>)+(<B>*<K>**2/<Re>**2)*(<n+ lim>-<n- lim>)*celldivgrad[l=2](<U>)
! var[3]*var[4]^2*someloop[42]*(var[i,31]-var[i,32])/var[1]^2+someloop[41]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(41,i,j)
      call update_someloop(42,i,j)
      
      var(45)%funk(ns)%v = var(45)%funk(ns)%v + (var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(42)%v*(var&
        &(31)%funk(nsvar(31,i))%v-var(32)%funk(nsvar(32,i))%v)/var(1)%funk(1)%v**2+someloop(41)%v)
      
      deriv = var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(42)%v/var(1)%funk(1)%v**2
      call add_to_dv(var(45)%funk(ns),deriv,var(31)%funk(nsvar(31,i)))
      
      deriv = -var(3)%funk(1)%v*var(4)%funk(1)%v**2*someloop(42)%v/var(1)%funk(1)%v**2
      call add_to_dv(var(45)%funk(ns),deriv,var(32)%funk(nsvar(32,i)))
      
      deriv = 1
      call add_to_dv(var(45)%funk(ns),deriv,someloop(41))
      
      deriv = var(3)%funk(1)%v*var(4)%funk(1)%v**2*(var(31)%funk(nsvar(31,i))%v-var(32)%funk(nsvar(32,i))&
        &%v)/var(1)%funk(1)%v**2
      call add_to_dv(var(45)%funk(ns),deriv,someloop(42))
      
    end do
    
  else if (m == 46) then
! equation <wall noflux>
! <u_f>
! var[j,27]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(46)%funk(ns)%v = var(46)%funk(ns)%v + (var(27)%funk(nsvar(27,j))%v)
      
      deriv = 1
      call add_to_dv(var(46)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
    end do
    
  else if (m == 47) then
! equation <wall noslip>
! dot(<u[l=:]>,<facetang1[l=:]>)
! someloop[44]*facetang1[j,2]+someloop[43]*facetang1[j,1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(43,i,j)
      call update_someloop(44,i,j)
      
      var(47)%funk(ns)%v = var(47)%funk(ns)%v + (someloop(44)%v*face(j)%norm(2,2)+someloop(43)%v*face(j)%&
        &norm(1,2))
      
      deriv = face(j)%norm(1,2)
      call add_to_dv(var(47)%funk(ns),deriv,someloop(43))
      
      deriv = face(j)%norm(2,2)
      call add_to_dv(var(47)%funk(ns),deriv,someloop(44))
      
    end do
    
  else if (m == 48) then
! equation <wall p extrapolation>
! dot(<graddivp[l=:]>,<facenorm[l=:]>)
! someloop[46]*facenorm[j,2]+someloop[45]*facenorm[j,1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(45,i,j)
      call update_someloop(46,i,j)
      
      var(48)%funk(ns)%v = var(48)%funk(ns)%v + (someloop(46)%v*face(j)%norm(2,1)+someloop(45)%v*face(j)%&
        &norm(1,1))
      
      deriv = face(j)%norm(1,1)
      call add_to_dv(var(48)%funk(ns),deriv,someloop(45))
      
      deriv = face(j)%norm(2,1)
      call add_to_dv(var(48)%funk(ns),deriv,someloop(46))
      
    end do
    
  else if (m == 49) then
! equation <outlet fully developed>
! facegrad(dot(<u[l=:]>,cellave[lastface](<facenorm[l=:]>)))
! someloop[47]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(47,i,j)
      
      var(49)%funk(ns)%v = var(49)%funk(ns)%v + (someloop(47)%v)
      
      deriv = 1
      call add_to_dv(var(49)%funk(ns),deriv,someloop(47))
      
    end do
    
  else if (m == 50) then
! equation <outlet noslip>
! dot(<u[l=:]>,<facetang1[l=:]>)
! someloop[49]*facetang1[j,2]+someloop[48]*facetang1[j,1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(48,i,j)
      call update_someloop(49,i,j)
      
      var(50)%funk(ns)%v = var(50)%funk(ns)%v + (someloop(49)%v*face(j)%norm(2,2)+someloop(48)%v*face(j)%&
        &norm(1,2))
      
      deriv = face(j)%norm(1,2)
      call add_to_dv(var(50)%funk(ns),deriv,someloop(48))
      
      deriv = face(j)%norm(2,2)
      call add_to_dv(var(50)%funk(ns),deriv,someloop(49))
      
    end do
    
  else if (m == 51) then
! equation <outlet p>
! <p>
! someloop[50]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(50,i,j)
      
      var(51)%funk(ns)%v = var(51)%funk(ns)%v + (someloop(50)%v)
      
      deriv = 1
      call add_to_dv(var(51)%funk(ns),deriv,someloop(50))
      
    end do
    
  else if (m == 52) then
! equation <inlet fully developed>
! facegrad(dot(<u[l=:]>,cellave[lastface](<facenorm[l=:]>)))
! someloop[51]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(51,i,j)
      
      var(52)%funk(ns)%v = var(52)%funk(ns)%v + (someloop(51)%v)
      
      deriv = 1
      call add_to_dv(var(52)%funk(ns),deriv,someloop(51))
      
    end do
    
  else if (m == 53) then
! equation <inlet noslip>
! dot(<u[l=:]>,<facetang1[l=:]>)
! someloop[53]*facetang1[j,2]+someloop[52]*facetang1[j,1]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(52,i,j)
      call update_someloop(53,i,j)
      
      var(53)%funk(ns)%v = var(53)%funk(ns)%v + (someloop(53)%v*face(j)%norm(2,2)+someloop(52)%v*face(j)%&
        &norm(1,2))
      
      deriv = face(j)%norm(1,2)
      call add_to_dv(var(53)%funk(ns),deriv,someloop(52))
      
      deriv = face(j)%norm(2,2)
      call add_to_dv(var(53)%funk(ns),deriv,someloop(53))
      
    end do
    
  else if (m == 54) then
! equation <p_in for flowrate>
! <u_av_calc>-1.d0
! var[30]-1.0
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      
      var(54)%funk(ns)%v = var(54)%funk(ns)%v + (var(30)%funk(1)%v-1.0)
      
      deriv = 1
      call add_to_dv(var(54)%funk(ns),deriv,var(30)%funk(1))
      
    end do
    
  else if (m == 55) then
! equation <inlet flowrate>
! <p>-<p_in>
! someloop[54]-var[14]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(54,i,j)
      
      var(55)%funk(ns)%v = var(55)%funk(ns)%v + (someloop(54)%v-var(14)%funk(1)%v)
      
      deriv = -1
      call add_to_dv(var(55)%funk(ns),deriv,var(14)%funk(1))
      
      deriv = 1
      call add_to_dv(var(55)%funk(ns),deriv,someloop(54))
      
    end do
    
  else if (m == 56) then
! equation <velocity symmetry [l=1]>
! facegrad(dot(<u[l=:]>,cellave[lastface](<facetang1[l=:]>)))
! someloop[55]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(55,i,j)
      
      var(56)%funk(ns)%v = var(56)%funk(ns)%v + (someloop(55)%v)
      
      deriv = 1
      call add_to_dv(var(56)%funk(ns),deriv,someloop(55))
      
    end do
    
  else if (m == 57) then
! equation <velocity symmetry [l=2]>
! <u_f>
! var[j,27]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(57)%funk(ns)%v = var(57)%funk(ns)%v + (var(27)%funk(nsvar(27,j))%v)
      
      deriv = 1
      call add_to_dv(var(57)%funk(ns),deriv,var(27)%funk(nsvar(27,j)))
      
    end do
    
  else if (m == 58) then
! equation <pressure symmetry>
! facegrad(<p>)
! someloop[56]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(56,i,j)
      
      var(58)%funk(ns)%v = var(58)%funk(ns)%v + (someloop(56)%v)
      
      deriv = 1
      call add_to_dv(var(58)%funk(ns),deriv,someloop(56))
      
    end do
    
  else if (m == 59) then
! equation <ion+ continuity>
! celldiv(<J+_f>)
! someloop[57]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(57,i,j)
      
      var(59)%funk(ns)%v = var(59)%funk(ns)%v + (someloop(57)%v)
      
      deriv = 1
      call add_to_dv(var(59)%funk(ns),deriv,someloop(57))
      
    end do
    
  else if (m == 60) then
! equation <ion- continuity>
! celldiv(<J-_f>)
! someloop[58]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(58,i,j)
      
      var(60)%funk(ns)%v = var(60)%funk(ns)%v + (someloop(58)%v)
      
      deriv = 1
      call add_to_dv(var(60)%funk(ns),deriv,someloop(58))
      
    end do
    
  else if (m == 61) then
! equation <ion+ symmetry>
! facegrad(<n+>)
! someloop[59]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(59,i,j)
      
      var(61)%funk(ns)%v = var(61)%funk(ns)%v + (someloop(59)%v)
      
      deriv = 1
      call add_to_dv(var(61)%funk(ns),deriv,someloop(59))
      
    end do
    
  else if (m == 62) then
! equation <ion- symmetry>
! facegrad(<n->)
! someloop[60]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(60,i,j)
      
      var(62)%funk(ns)%v = var(62)%funk(ns)%v + (someloop(60)%v)
      
      deriv = 1
      call add_to_dv(var(62)%funk(ns),deriv,someloop(60))
      
    end do
    
  else if (m == 63) then
! equation <ion+ outlet>
! facegrad(<n+>)
! someloop[61]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(61,i,j)
      
      var(63)%funk(ns)%v = var(63)%funk(ns)%v + (someloop(61)%v)
      
      deriv = 1
      call add_to_dv(var(63)%funk(ns),deriv,someloop(61))
      
    end do
    
  else if (m == 64) then
! equation <ion- outlet>
! facegrad(<n->)
! someloop[62]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(62,i,j)
      
      var(64)%funk(ns)%v = var(64)%funk(ns)%v + (someloop(62)%v)
      
      deriv = 1
      call add_to_dv(var(64)%funk(ns),deriv,someloop(62))
      
    end do
    
  else if (m == 65) then
! equation <ion+ walls>
! <J+_f>
! var[j,37]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(65)%funk(ns)%v = var(65)%funk(ns)%v + (var(37)%funk(nsvar(37,j))%v)
      
      deriv = 1
      call add_to_dv(var(65)%funk(ns),deriv,var(37)%funk(nsvar(37,j)))
      
    end do
    
  else if (m == 66) then
! equation <ion- walls>
! <J-_f>
! var[j,38]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(66)%funk(ns)%v = var(66)%funk(ns)%v + (var(38)%funk(nsvar(38,j))%v)
      
      deriv = 1
      call add_to_dv(var(66)%funk(ns),deriv,var(38)%funk(nsvar(38,j)))
      
    end do
    
  else if (m == 67) then
! equation <ion+ inlet>
! facegrad(<n+>)
! someloop[63]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(63,i,j)
      
      var(67)%funk(ns)%v = var(67)%funk(ns)%v + (someloop(63)%v)
      
      deriv = 1
      call add_to_dv(var(67)%funk(ns),deriv,someloop(63))
      
    end do
    
  else if (m == 68) then
! equation <ion- inlet>
! <n+ lim>*<n- lim>-1.d0
! someloop[64]*someloop[65]-1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(64,i,j)
      call update_someloop(65,i,j)
      
      var(68)%funk(ns)%v = var(68)%funk(ns)%v + (someloop(64)%v*someloop(65)%v-1.0)
      
      deriv = someloop(65)%v
      call add_to_dv(var(68)%funk(ns),deriv,someloop(64))
      
      deriv = someloop(64)%v
      call add_to_dv(var(68)%funk(ns),deriv,someloop(65))
      
    end do
    
  else if (m == 69) then
! equation <I_total equation>
! <I_total_calc>-<I_total>
! var[41]-var[6]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      
      var(69)%funk(ns)%v = var(69)%funk(ns)%v + (var(41)%funk(1)%v-var(6)%funk(1)%v)
      
      deriv = 1
      call add_to_dv(var(69)%funk(ns),deriv,var(41)%funk(1))
      
    end do
    
  else if (m == 70) then
! equation <U poisson equation>
! celldiv(facegrad(<U>))+<K>**2*(<n+ lim>-<n- lim>)/2.d0
! 0.5*var[4]^2*(var[i,31]-var[i,32])+someloop[66]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(66,i,j)
      
      var(70)%funk(ns)%v = var(70)%funk(ns)%v + (0.5*var(4)%funk(1)%v**2*(var(31)%funk(nsvar(31,i))%v-var&
        &(32)%funk(nsvar(32,i))%v)+someloop(66)%v)
      
      deriv = 0.5*var(4)%funk(1)%v**2
      call add_to_dv(var(70)%funk(ns),deriv,var(31)%funk(nsvar(31,i)))
      
      deriv = -0.5*var(4)%funk(1)%v**2
      call add_to_dv(var(70)%funk(ns),deriv,var(32)%funk(nsvar(32,i)))
      
      deriv = 1
      call add_to_dv(var(70)%funk(ns),deriv,someloop(66))
      
    end do
    
  else if (m == 71) then
! equation <U symmetry>
! facegrad(<U>)
! someloop[67]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(67,i,j)
      
      var(71)%funk(ns)%v = var(71)%funk(ns)%v + (someloop(67)%v)
      
      deriv = 1
      call add_to_dv(var(71)%funk(ns),deriv,someloop(67))
      
    end do
    
  else if (m == 72) then
! equation <U walls>
! facegrad(<U>)-<S>
! someloop[68]-var[5]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(68,i,j)
      
      var(72)%funk(ns)%v = var(72)%funk(ns)%v + (someloop(68)%v-var(5)%funk(1)%v)
      
      deriv = 1
      call add_to_dv(var(72)%funk(ns),deriv,someloop(68))
      
    end do
    
  else if (m == 73) then
! equation <U inlet>
! facegrad(<U>)+<dUdx inlet>
! someloop[69]+var[17]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(69,i,j)
      
      var(73)%funk(ns)%v = var(73)%funk(ns)%v + (someloop(69)%v+var(17)%funk(1)%v)
      
      deriv = 1
      call add_to_dv(var(73)%funk(ns),deriv,var(17)%funk(1))
      
      deriv = 1
      call add_to_dv(var(73)%funk(ns),deriv,someloop(69))
      
    end do
    
  else if (m == 74) then
! equation <U inlet centreline>
! <U>
! someloop[70]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(70,i,j)
      
      var(74)%funk(ns)%v = var(74)%funk(ns)%v + (someloop(70)%v)
      
      deriv = 1
      call add_to_dv(var(74)%funk(ns),deriv,someloop(70))
      
    end do
    
  else if (m == 75) then
! equation <U outlet>
! facegrad(<U>)-<dUdx outlet>
! someloop[71]-var[42]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      j = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(71,i,j)
      
      var(75)%funk(ns)%v = var(75)%funk(ns)%v + (someloop(71)%v-var(42)%funk(1)%v)
      
      deriv = -1
      call add_to_dv(var(75)%funk(ns),deriv,var(42)%funk(1))
      
      deriv = 1
      call add_to_dv(var(75)%funk(ns),deriv,someloop(71))
      
    end do
    
    
  else
    write(*,*) "ERROR: the index ",m," was not found when updating equation"
    stop
  end if


  if (debug) then
    formatline = '(a,'//trim(indexformat)//',a,i3,a,a)'
    do ns = 1, ubound(var(m)%funk,1)
      write(*,fmt=formatline) '(ns,m) = (',ns,',',m,'): var = ',trim(print_funk(var(m)%funk(ns)))
    end do
  end if

end do

if (debug) write(*,'(a/40(1h-))') 'equation updates'

if (debug) write(*,'(a/80(1h-))') 'subroutine update'

end subroutine update

!----------------------------------------------------------------------------

recursive subroutine update_someloop(m,ilast,jlast)

! here we update each of all the possible someloops
! bug wife again!!!

use general_module
integer :: m, ilast, jlast, i, j, ns, region_number, flux_direction
double precision :: deriv
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine update_someloop'

i = ilast
j = jlast

call reset_funk(someloop(m))

if (m == 1) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=1]>
! SYSTEM generated sum someloop over cell region <facekernel[l=1]>
! var[i,11]*facekernel[j,1,ns]
  
! sum is conducted around region <facekernel[l=1]>
  do ns = 1, ubound(face(j)%kernel(1)%ijk,1)
    i = face(j)%kernel(1)%ijk(ns)
    
    someloop(1)%v = someloop(1)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(1)%v(ns))
    
    deriv = face(j)%kernel(1)%v(ns)
    call add_to_dv(someloop(1),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 2) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(2)%v = someloop(2)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(2),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 3) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=2]>
! SYSTEM generated sum someloop over cell region <facekernel[l=2]>
! var[i,11]*facekernel[j,2,ns]
  
! sum is conducted around region <facekernel[l=2]>
  do ns = 1, ubound(face(j)%kernel(2)%ijk,1)
    i = face(j)%kernel(2)%ijk(ns)
    
    someloop(3)%v = someloop(3)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(2)%v(ns))
    
    deriv = face(j)%kernel(2)%v(ns)
    call add_to_dv(someloop(3),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 4) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=1]>
! SYSTEM generated sum someloop over cell region <facekernel[l=1]>
! var[i,12]*facekernel[j,1,ns]
  
! sum is conducted around region <facekernel[l=1]>
  do ns = 1, ubound(face(j)%kernel(1)%ijk,1)
    i = face(j)%kernel(1)%ijk(ns)
    
    someloop(4)%v = someloop(4)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(1)%v(ns))
    
    deriv = face(j)%kernel(1)%v(ns)
    call add_to_dv(someloop(4),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 5) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=2]>
! SYSTEM generated sum someloop over cell region <facekernel[l=2]>
! var[i,12]*facekernel[j,2,ns]
  
! sum is conducted around region <facekernel[l=2]>
  do ns = 1, ubound(face(j)%kernel(2)%ijk,1)
    i = face(j)%kernel(2)%ijk(ns)
    
    someloop(5)%v = someloop(5)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(2)%v(ns))
    
    deriv = face(j)%kernel(2)%v(ns)
    call add_to_dv(someloop(5),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 6) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(6)%v = someloop(6)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(6),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 7) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! someloop[78]*divop[i,j]*facenorm[j,1]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(78,i,j)
    
    someloop(7)%v = someloop(7)%v + (someloop(78)%v*divop(i,j)*face(j)%norm(1,1))
    
    deriv = divop(i,j)*face(j)%norm(1,1)
    call add_to_dv(someloop(7),deriv,someloop(78))
    
  end do
  
else if (m == 8) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! someloop[79]*divop[i,j]*facenorm[j,2]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(79,i,j)
    
    someloop(8)%v = someloop(8)%v + (someloop(79)%v*divop(i,j)*face(j)%norm(2,1))
    
    deriv = divop(i,j)*face(j)%norm(2,1)
    call add_to_dv(someloop(8),deriv,someloop(79))
    
  end do
  
else if (m == 9) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,13]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(9)%v = someloop(9)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(9),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 10) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,23]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(10)%v = someloop(10)%v + (var(23)%funk(nsvar(23,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(10),deriv,var(23)%funk(nsvar(23,i)))
    
  end do
  
else if (m == 11) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,24]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(11)%v = someloop(11)%v + (var(24)%funk(nsvar(24,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(11),deriv,var(24)%funk(nsvar(24,i)))
    
  end do
  
else if (m == 12) then
! someloop SYSTEM generated max someloop over face region <noloop>
! SYSTEM generated max someloop over face region <noloop>
! abs(var[j,25])
  
! update default expression outside main loop
! 1.d-6
  
  someloop(12)%v = 9.999999999999999e-7
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    if (abs(var(25)%funk(nsvar(25,j))%v)>someloop(12)%v) then
      call reset_funk(someloop(m))
      someloop(12)%v = abs(var(25)%funk(nsvar(25,j))%v)
      
      deriv = var(25)%funk(nsvar(25,j))%v/abs(var(25)%funk(nsvar(25,j))%v)
      call add_to_dv(someloop(12),deriv,var(25)%funk(nsvar(25,j)))
      
    end if
  end do
  
else if (m == 13) then
! someloop SYSTEM generated min someloop over face region <noloop>
! SYSTEM generated min someloop over face region <noloop>
! var[1]*facedx[j]^2
  
! update default expression outside main loop
!  sqrt(facedx[j]/(someloop[12])) 
  call update_someloop(12,i,j)
  
  someloop(13)%v = sqrt(face(j)%dx/someloop(12)%v)
  
  deriv = -face(j)%dx/(someloop(12)%v**2*sqrt(face(j)%dx/someloop(12)%v))/2.0
  call add_to_dv(someloop(13),deriv,someloop(12))
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    if (var(1)%funk(1)%v*face(j)%dx**2<someloop(13)%v) then
      call reset_funk(someloop(m))
      someloop(13)%v = var(1)%funk(1)%v*face(j)%dx**2
      
    end if
  end do
  
else if (m == 14) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,11]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(14)%v = someloop(14)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(14),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 15) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,12]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(15)%v = someloop(15)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(15),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 16) then
! someloop SYSTEM generated sum someloop over cell region <upwindfaceicells>
! SYSTEM generated sum someloop over cell region <upwindfaceicells>
! var[i,11]+var[8]*someloop[84]*(someloop[85]-cellx[i,3])+var[8]*someloop[82]*(someloop[83]-cellx[i,2])+var[8]*someloop[80]*(someloop[81]-cellx[i,1])
  
! update flux expression outside main loop
! var[j,27]
  
  flux_direction = nint(sign(1.d0,var(27)%funk(nsvar(27,j))%v))
! sum is conducted around region <upwindfaceicells>
  do ns = (3-flux_direction)/2, (3-flux_direction)/2
    i = face(j)%icell(ns)
    call update_someloop(80,i,j)
    call update_someloop(81,i,j)
    call update_someloop(82,i,j)
    call update_someloop(83,i,j)
    call update_someloop(84,i,j)
    call update_someloop(85,i,j)
    
    someloop(16)%v = someloop(16)%v + (var(11)%funk(nsvar(11,i))%v+var(8)%funk(1)%v*someloop(84)%v*(som&
      &eloop(85)%v-cell(i)%x(3))+var(8)%funk(1)%v*someloop(82)%v*(someloop(83)%v-cell(i)%x(2))+var&
      &(8)%funk(1)%v*someloop(80)%v*(someloop(81)%v-cell(i)%x(1)))
    
    deriv = 1
    call add_to_dv(someloop(16),deriv,var(11)%funk(nsvar(11,i)))
    
    deriv = var(8)%funk(1)%v*(someloop(81)%v-cell(i)%x(1))
    call add_to_dv(someloop(16),deriv,someloop(80))
    
    deriv = var(8)%funk(1)%v*someloop(80)%v
    call add_to_dv(someloop(16),deriv,someloop(81))
    
    deriv = var(8)%funk(1)%v*(someloop(83)%v-cell(i)%x(2))
    call add_to_dv(someloop(16),deriv,someloop(82))
    
    deriv = var(8)%funk(1)%v*someloop(82)%v
    call add_to_dv(someloop(16),deriv,someloop(83))
    
    deriv = var(8)%funk(1)%v*(someloop(85)%v-cell(i)%x(3))
    call add_to_dv(someloop(16),deriv,someloop(84))
    
    deriv = var(8)%funk(1)%v*someloop(84)%v
    call add_to_dv(someloop(16),deriv,someloop(85))
    
  end do
  
else if (m == 17) then
! someloop SYSTEM generated sum someloop over cell region <upwindfaceicells>
! SYSTEM generated sum someloop over cell region <upwindfaceicells>
! var[i,12]+var[8]*someloop[90]*(someloop[91]-cellx[i,3])+var[8]*someloop[88]*(someloop[89]-cellx[i,2])+var[8]*someloop[86]*(someloop[87]-cellx[i,1])
  
! update flux expression outside main loop
! var[j,27]
  
  flux_direction = nint(sign(1.d0,var(27)%funk(nsvar(27,j))%v))
! sum is conducted around region <upwindfaceicells>
  do ns = (3-flux_direction)/2, (3-flux_direction)/2
    i = face(j)%icell(ns)
    call update_someloop(86,i,j)
    call update_someloop(87,i,j)
    call update_someloop(88,i,j)
    call update_someloop(89,i,j)
    call update_someloop(90,i,j)
    call update_someloop(91,i,j)
    
    someloop(17)%v = someloop(17)%v + (var(12)%funk(nsvar(12,i))%v+var(8)%funk(1)%v*someloop(90)%v*(som&
      &eloop(91)%v-cell(i)%x(3))+var(8)%funk(1)%v*someloop(88)%v*(someloop(89)%v-cell(i)%x(2))+var&
      &(8)%funk(1)%v*someloop(86)%v*(someloop(87)%v-cell(i)%x(1)))
    
    deriv = 1
    call add_to_dv(someloop(17),deriv,var(12)%funk(nsvar(12,i)))
    
    deriv = var(8)%funk(1)%v*(someloop(87)%v-cell(i)%x(1))
    call add_to_dv(someloop(17),deriv,someloop(86))
    
    deriv = var(8)%funk(1)%v*someloop(86)%v
    call add_to_dv(someloop(17),deriv,someloop(87))
    
    deriv = var(8)%funk(1)%v*(someloop(89)%v-cell(i)%x(2))
    call add_to_dv(someloop(17),deriv,someloop(88))
    
    deriv = var(8)%funk(1)%v*someloop(88)%v
    call add_to_dv(someloop(17),deriv,someloop(89))
    
    deriv = var(8)%funk(1)%v*(someloop(91)%v-cell(i)%x(3))
    call add_to_dv(someloop(17),deriv,someloop(90))
    
    deriv = var(8)%funk(1)%v*someloop(90)%v
    call add_to_dv(someloop(17),deriv,someloop(91))
    
  end do
  
else if (m == 18) then
! someloop SYSTEM generated sum someloop over face region <inlet>
! SYSTEM generated sum someloop over face region <inlet>
! -facearea[j]*var[j,27]
  
  region_number = region_number_from_name(name='<inlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <inlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(18)%v = someloop(18)%v + (-face(j)%area*var(27)%funk(nsvar(27,j))%v)
    
    deriv = -face(j)%area
    call add_to_dv(someloop(18),deriv,var(27)%funk(nsvar(27,j)))
    
  end do
  
else if (m == 19) then
! someloop SYSTEM generated sum someloop over face region <inlet>
! SYSTEM generated sum someloop over face region <inlet>
! facearea[j]
  
  region_number = region_number_from_name(name='<inlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <inlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(19)%v = someloop(19)%v + (face(j)%area)
    
  end do
  
else if (m == 20) then
! someloop SYSTEM generated max someloop over cell region <noloop>
! SYSTEM generated max someloop over cell region <noloop>
! var[i,15]
  
! update default expression outside main loop
! var[10]
  
  someloop(20)%v = var(10)%funk(1)%v
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    if (var(15)%funk(nsvar(15,i))%v>someloop(20)%v) then
      call reset_funk(someloop(m))
      someloop(20)%v = var(15)%funk(nsvar(15,i))%v
      
      deriv = 1
      call add_to_dv(someloop(20),deriv,var(15)%funk(nsvar(15,i)))
      
    end if
  end do
  
else if (m == 21) then
! someloop SYSTEM generated max someloop over cell region <noloop>
! SYSTEM generated max someloop over cell region <noloop>
! var[i,16]
  
! update default expression outside main loop
! var[10]
  
  someloop(21)%v = var(10)%funk(1)%v
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    if (var(16)%funk(nsvar(16,i))%v>someloop(21)%v) then
      call reset_funk(someloop(m))
      someloop(21)%v = var(16)%funk(nsvar(16,i))%v
      
      deriv = 1
      call add_to_dv(someloop(21),deriv,var(16)%funk(nsvar(16,i)))
      
    end if
  end do
  
else if (m == 22) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[92]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(92,i,j)
    
    someloop(22)%v = someloop(22)%v + (someloop(92)%v)
    
    deriv = 1
    call add_to_dv(someloop(22),deriv,someloop(92))
    
  end do
  
else if (m == 23) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[93]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(93,i,j)
    
    someloop(23)%v = someloop(23)%v + (someloop(93)%v)
    
    deriv = 1
    call add_to_dv(someloop(23),deriv,someloop(93))
    
  end do
  
else if (m == 24) then
! someloop SYSTEM generated max someloop over face region <noloop>
! SYSTEM generated max someloop over face region <noloop>
! someloop[94]
  
! update default expression outside main loop
! var[10]
  
  someloop(24)%v = var(10)%funk(1)%v
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    call update_someloop(94,i,j)
    
    if (someloop(94)%v>someloop(24)%v) then
      call reset_funk(someloop(m))
      someloop(24)%v = someloop(94)%v
      
      deriv = 1
      call add_to_dv(someloop(24),deriv,someloop(94))
      
    end if
  end do
  
else if (m == 25) then
! someloop SYSTEM generated max someloop over face region <noloop>
! SYSTEM generated max someloop over face region <noloop>
! someloop[95]
  
! update default expression outside main loop
! var[10]
  
  someloop(25)%v = var(10)%funk(1)%v
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    call update_someloop(95,i,j)
    
    if (someloop(95)%v>someloop(25)%v) then
      call reset_funk(someloop(m))
      someloop(25)%v = someloop(95)%v
      
      deriv = 1
      call add_to_dv(someloop(25),deriv,someloop(95))
      
    end if
  end do
  
else if (m == 26) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,15]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(26)%v = someloop(26)%v + (var(15)%funk(nsvar(15,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(26),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 27) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(27)%v = someloop(27)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(27),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 28) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,31]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(28)%v = someloop(28)%v + (var(31)%funk(nsvar(31,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(28),deriv,var(31)%funk(nsvar(31,i)))
    
  end do
  
else if (m == 29) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,16]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(29)%v = someloop(29)%v + (var(16)%funk(nsvar(16,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(29),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 30) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(30)%v = someloop(30)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(30),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 31) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,32]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(31)%v = someloop(31)%v + (var(32)%funk(nsvar(32,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(31),deriv,var(32)%funk(nsvar(32,i)))
    
  end do
  
else if (m == 32) then
! someloop SYSTEM generated sum someloop over face region <inlet>
! SYSTEM generated sum someloop over face region <inlet>
! facearea[j]*var[j,37]
  
  region_number = region_number_from_name(name='<inlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <inlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(32)%v = someloop(32)%v + (face(j)%area*var(37)%funk(nsvar(37,j))%v)
    
    deriv = face(j)%area
    call add_to_dv(someloop(32),deriv,var(37)%funk(nsvar(37,j)))
    
  end do
  
else if (m == 33) then
! someloop SYSTEM generated sum someloop over face region <inlet>
! SYSTEM generated sum someloop over face region <inlet>
! -facearea[j]*var[j,38]
  
  region_number = region_number_from_name(name='<inlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <inlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(33)%v = someloop(33)%v + (-face(j)%area*var(38)%funk(nsvar(38,j))%v)
    
    deriv = -face(j)%area
    call add_to_dv(someloop(33),deriv,var(38)%funk(nsvar(38,j)))
    
  end do
  
else if (m == 34) then
! someloop SYSTEM generated sum someloop over face region <walls>
! SYSTEM generated sum someloop over face region <walls>
! var[5]*facearea[j]
  
  region_number = region_number_from_name(name='<walls>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <walls> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(34)%v = someloop(34)%v + (var(5)%funk(1)%v*face(j)%area)
    
  end do
  
else if (m == 35) then
! someloop SYSTEM generated sum someloop over face region <inlet>
! SYSTEM generated sum someloop over face region <inlet>
! var[17]*facearea[j]
  
  region_number = region_number_from_name(name='<inlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <inlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(35)%v = someloop(35)%v + (var(17)%funk(1)%v*face(j)%area)
    
    deriv = face(j)%area
    call add_to_dv(someloop(35),deriv,var(17)%funk(1))
    
  end do
  
else if (m == 36) then
! someloop SYSTEM generated sum someloop over cell region <domain>
! SYSTEM generated sum someloop over cell region <domain>
! cellvol[i]*(var[i,15]-var[i,16])
  
  region_number = region_number_from_name(name='<domain>',centring='cell')
  if (region_number == 0) stop 'ERROR: problem finding cell region <domain> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    i = region(region_number)%ij(ns)
    
    someloop(36)%v = someloop(36)%v + (cell(i)%vol*(var(15)%funk(nsvar(15,i))%v-var(16)%funk(nsvar(16,i&
      &))%v))
    
    deriv = cell(i)%vol
    call add_to_dv(someloop(36),deriv,var(15)%funk(nsvar(15,i)))
    
    deriv = -cell(i)%vol
    call add_to_dv(someloop(36),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 37) then
! someloop SYSTEM generated sum someloop over face region <outlet>
! SYSTEM generated sum someloop over face region <outlet>
! facearea[j]
  
  region_number = region_number_from_name(name='<outlet>',centring='face')
  if (region_number == 0) stop 'ERROR: problem finding face region <outlet> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    j = region(region_number)%ij(ns)
    
    someloop(37)%v = someloop(37)%v + (face(j)%area)
    
  end do
  
else if (m == 38) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! divop[i,j]*var[j,27]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    
    someloop(38)%v = someloop(38)%v + (divop(i,j)*var(27)%funk(nsvar(27,j))%v)
    
    deriv = divop(i,j)
    call add_to_dv(someloop(38),deriv,var(27)%funk(nsvar(27,j)))
    
  end do
  
else if (m == 39) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! divop[i,j]*var[j,28]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    
    someloop(39)%v = someloop(39)%v + (divop(i,j)*var(28)%funk(nsvar(28,j))%v)
    
    deriv = divop(i,j)
    call add_to_dv(someloop(39),deriv,var(28)%funk(nsvar(28,j)))
    
  end do
  
else if (m == 40) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! someloop[96]*divop[i,j]*facenorm[j,1]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(96,i,j)
    
    someloop(40)%v = someloop(40)%v + (someloop(96)%v*divop(i,j)*face(j)%norm(1,1))
    
    deriv = divop(i,j)*face(j)%norm(1,1)
    call add_to_dv(someloop(40),deriv,someloop(96))
    
  end do
  
else if (m == 41) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! divop[i,j]*var[j,29]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    
    someloop(41)%v = someloop(41)%v + (divop(i,j)*var(29)%funk(nsvar(29,j))%v)
    
    deriv = divop(i,j)
    call add_to_dv(someloop(41),deriv,var(29)%funk(nsvar(29,j)))
    
  end do
  
else if (m == 42) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! someloop[97]*divop[i,j]*facenorm[j,2]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(97,i,j)
    
    someloop(42)%v = someloop(42)%v + (someloop(97)%v*divop(i,j)*face(j)%norm(2,1))
    
    deriv = divop(i,j)*face(j)%norm(2,1)
    call add_to_dv(someloop(42),deriv,someloop(97))
    
  end do
  
else if (m == 43) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,11]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(43)%v = someloop(43)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(43),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 44) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,12]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(44)%v = someloop(44)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(44),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 45) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,23]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(45)%v = someloop(45)%v + (var(23)%funk(nsvar(23,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(45),deriv,var(23)%funk(nsvar(23,i)))
    
  end do
  
else if (m == 46) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,24]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(46)%v = someloop(46)%v + (var(24)%funk(nsvar(24,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(46),deriv,var(24)%funk(nsvar(24,i)))
    
  end do
  
else if (m == 47) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! (someloop[99]*var[i,12]+someloop[98]*var[i,11])*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    call update_someloop(98,i,j)
    call update_someloop(99,i,j)
    
    someloop(47)%v = someloop(47)%v + ((someloop(99)%v*var(12)%funk(nsvar(12,i))%v+someloop(98)%v*var(1&
      &1)%funk(nsvar(11,i))%v)*face(j)%kernel(4)%v(ns))
    
    deriv = someloop(98)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(47),deriv,var(11)%funk(nsvar(11,i)))
    
    deriv = someloop(99)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(47),deriv,var(12)%funk(nsvar(12,i)))
    
    deriv = var(11)%funk(nsvar(11,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(47),deriv,someloop(98))
    
    deriv = var(12)%funk(nsvar(12,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(47),deriv,someloop(99))
    
  end do
  
else if (m == 48) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,11]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(48)%v = someloop(48)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(48),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 49) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,12]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(49)%v = someloop(49)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(49),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 50) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(50)%v = someloop(50)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(50),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 51) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! (someloop[102]*var[i,12]+someloop[101]*var[i,11])*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    call update_someloop(101,i,j)
    call update_someloop(102,i,j)
    
    someloop(51)%v = someloop(51)%v + ((someloop(102)%v*var(12)%funk(nsvar(12,i))%v+someloop(101)%v*var&
      &(11)%funk(nsvar(11,i))%v)*face(j)%kernel(4)%v(ns))
    
    deriv = someloop(101)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(51),deriv,var(11)%funk(nsvar(11,i)))
    
    deriv = someloop(102)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(51),deriv,var(12)%funk(nsvar(12,i)))
    
    deriv = var(11)%funk(nsvar(11,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(51),deriv,someloop(101))
    
    deriv = var(12)%funk(nsvar(12,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(51),deriv,someloop(102))
    
  end do
  
else if (m == 52) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,11]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(52)%v = someloop(52)%v + (var(11)%funk(nsvar(11,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(52),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 53) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,12]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(53)%v = someloop(53)%v + (var(12)%funk(nsvar(12,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(53),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 54) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(54)%v = someloop(54)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(54),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 55) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! (someloop[105]*var[i,12]+someloop[104]*var[i,11])*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    call update_someloop(104,i,j)
    call update_someloop(105,i,j)
    
    someloop(55)%v = someloop(55)%v + ((someloop(105)%v*var(12)%funk(nsvar(12,i))%v+someloop(104)%v*var&
      &(11)%funk(nsvar(11,i))%v)*face(j)%kernel(4)%v(ns))
    
    deriv = someloop(104)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(55),deriv,var(11)%funk(nsvar(11,i)))
    
    deriv = someloop(105)%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(55),deriv,var(12)%funk(nsvar(12,i)))
    
    deriv = var(11)%funk(nsvar(11,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(55),deriv,someloop(104))
    
    deriv = var(12)%funk(nsvar(12,i))%v*face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(55),deriv,someloop(105))
    
  end do
  
else if (m == 56) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,13]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(56)%v = someloop(56)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(56),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 57) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! divop[i,j]*var[j,37]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    
    someloop(57)%v = someloop(57)%v + (divop(i,j)*var(37)%funk(nsvar(37,j))%v)
    
    deriv = divop(i,j)
    call add_to_dv(someloop(57),deriv,var(37)%funk(nsvar(37,j)))
    
  end do
  
else if (m == 58) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! divop[i,j]*var[j,38]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    
    someloop(58)%v = someloop(58)%v + (divop(i,j)*var(38)%funk(nsvar(38,j))%v)
    
    deriv = divop(i,j)
    call add_to_dv(someloop(58),deriv,var(38)%funk(nsvar(38,j)))
    
  end do
  
else if (m == 59) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,15]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(59)%v = someloop(59)%v + (var(15)%funk(nsvar(15,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(59),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 60) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,16]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(60)%v = someloop(60)%v + (var(16)%funk(nsvar(16,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(60),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 61) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,15]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(61)%v = someloop(61)%v + (var(15)%funk(nsvar(15,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(61),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 62) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,16]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(62)%v = someloop(62)%v + (var(16)%funk(nsvar(16,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(62),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 63) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,15]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(63)%v = someloop(63)%v + (var(15)%funk(nsvar(15,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(63),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 64) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,31]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(64)%v = someloop(64)%v + (var(31)%funk(nsvar(31,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(64),deriv,var(31)%funk(nsvar(31,i)))
    
  end do
  
else if (m == 65) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,32]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(65)%v = someloop(65)%v + (var(32)%funk(nsvar(32,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(65),deriv,var(32)%funk(nsvar(32,i)))
    
  end do
  
else if (m == 66) then
! someloop SYSTEM generated sum someloop over face region <nobcelljfaces>
! SYSTEM generated sum someloop over face region <nobcelljfaces>
! someloop[107]*divop[i,j]
  
! sum is conducted around region <nobcelljfaces>
! move facesum to domain cell if cell is a boundary cell
  if (cell(i)%type == 2) i = face(cell(i)%jface(1))%icell(1)
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(107,i,j)
    
    someloop(66)%v = someloop(66)%v + (someloop(107)%v*divop(i,j))
    
    deriv = divop(i,j)
    call add_to_dv(someloop(66),deriv,someloop(107))
    
  end do
  
else if (m == 67) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(67)%v = someloop(67)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(67),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 68) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(68)%v = someloop(68)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(68),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 69) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(69)%v = someloop(69)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(69),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 70) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,18]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(70)%v = someloop(70)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(70),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 71) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(71)%v = someloop(71)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(71),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 72) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,77]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(72)%v = someloop(72)%v + (var(77)%funk(nsvar(77,i))%v*cell(ilast)%kernel(1)%v(ns))
  end do
  
else if (m == 73) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,77]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(73)%v = someloop(73)%v + (var(77)%funk(nsvar(77,i))%v*cell(ilast)%kernel(2)%v(ns))
  end do
  
else if (m == 74) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,77]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(74)%v = someloop(74)%v + (var(77)%funk(nsvar(77,i))%v*cell(ilast)%kernel(3)%v(ns))
  end do
  
else if (m == 75) then
! someloop SYSTEM generated sum someloop over cell region <all cells>
! SYSTEM generated sum someloop over cell region <all cells>
! var[i,83]
  
  region_number = region_number_from_name(name='<all cells>',centring='cell')
  if (region_number == 0) stop 'ERROR: problem finding cell region <all cells> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    i = region(region_number)%ij(ns)
    
    someloop(75)%v = someloop(75)%v + (var(83)%funk(nsvar(83,i))%v)
  end do
  
else if (m == 76) then
! someloop SYSTEM generated sum someloop over cell region <all cells>
! SYSTEM generated sum someloop over cell region <all cells>
! 1.0
  
  region_number = region_number_from_name(name='<all cells>',centring='cell')
  if (region_number == 0) stop 'ERROR: problem finding cell region <all cells> in update_someloops'
  
  do ns = 1, ubound(region(region_number)%ij,1)
    i = region(region_number)%ij(ns)
    
    someloop(76)%v = someloop(76)%v + (1.0)
  end do
  
else if (m == 77) then
! someloop SYSTEM generated max someloop over cell region <noloop>
! SYSTEM generated max someloop over cell region <noloop>
! var[i,83]
  
! update default expression outside main loop
! var[84]
  
  someloop(77)%v = var(84)%funk(1)%v
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    if (var(83)%funk(nsvar(83,i))%v>someloop(77)%v) then
      call reset_funk(someloop(m))
      someloop(77)%v = var(83)%funk(nsvar(83,i))%v
    end if
  end do
  
else if (m == 78) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(78)%v = someloop(78)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(78),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 79) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,13]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(79)%v = someloop(79)%v + (var(13)%funk(nsvar(13,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(79),deriv,var(13)%funk(nsvar(13,i)))
    
  end do
  
else if (m == 80) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,11]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(80)%v = someloop(80)%v + (var(11)%funk(nsvar(11,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(80),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 81) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(81)%v = someloop(81)%v + (face(j)%x(1))
    
  end do
  
else if (m == 82) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,11]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(82)%v = someloop(82)%v + (var(11)%funk(nsvar(11,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(82),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 83) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(83)%v = someloop(83)%v + (face(j)%x(2))
    
  end do
  
else if (m == 84) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,11]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(84)%v = someloop(84)%v + (var(11)%funk(nsvar(11,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(84),deriv,var(11)%funk(nsvar(11,i)))
    
  end do
  
else if (m == 85) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(85)%v = someloop(85)%v + (face(j)%x(3))
    
  end do
  
else if (m == 86) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,12]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(86)%v = someloop(86)%v + (var(12)%funk(nsvar(12,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(86),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 87) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(87)%v = someloop(87)%v + (face(j)%x(1))
    
  end do
  
else if (m == 88) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,12]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(88)%v = someloop(88)%v + (var(12)%funk(nsvar(12,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(88),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 89) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(89)%v = someloop(89)%v + (face(j)%x(2))
    
  end do
  
else if (m == 90) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,12]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(90)%v = someloop(90)%v + (var(12)%funk(nsvar(12,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(90),deriv,var(12)%funk(nsvar(12,i)))
    
  end do
  
else if (m == 91) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(91)%v = someloop(91)%v + (face(j)%x(3))
    
  end do
  
else if (m == 92) then
! someloop SYSTEM generated min someloop over cell region <noloop>
! SYSTEM generated min someloop over cell region <noloop>
! someloop[108]/(someloop[109]-limitertolerance)
  
! update default expression outside main loop
! 1.d0
  
  someloop(92)%v = 1.0
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(108,i,j)
    call update_someloop(109,i,j)
    
    if (someloop(108)%v/(someloop(109)%v-limitertolerance)<someloop(92)%v) then
      call reset_funk(someloop(m))
      someloop(92)%v = someloop(108)%v/(someloop(109)%v-limitertolerance)
      
      deriv = 1/(someloop(109)%v-limitertolerance)
      call add_to_dv(someloop(92),deriv,someloop(108))
      
      deriv = -someloop(108)%v/(someloop(109)%v-limitertolerance)**2
      call add_to_dv(someloop(92),deriv,someloop(109))
      
    end if
  end do
  
else if (m == 93) then
! someloop SYSTEM generated min someloop over cell region <noloop>
! SYSTEM generated min someloop over cell region <noloop>
! someloop[110]/(someloop[111]-limitertolerance)
  
! update default expression outside main loop
! 1.d0
  
  someloop(93)%v = 1.0
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(110,i,j)
    call update_someloop(111,i,j)
    
    if (someloop(110)%v/(someloop(111)%v-limitertolerance)<someloop(93)%v) then
      call reset_funk(someloop(m))
      someloop(93)%v = someloop(110)%v/(someloop(111)%v-limitertolerance)
      
      deriv = 1/(someloop(111)%v-limitertolerance)
      call add_to_dv(someloop(93),deriv,someloop(110))
      
      deriv = -someloop(110)%v/(someloop(111)%v-limitertolerance)**2
      call add_to_dv(someloop(93),deriv,someloop(111))
      
    end if
  end do
  
else if (m == 94) then
! someloop SYSTEM generated sum someloop over cell region <upwindfaceicells>
! SYSTEM generated sum someloop over cell region <upwindfaceicells>
! var[9]*someloop[116]*(someloop[117]-cellx[i,3])*var[i,33]+var[9]*someloop[114]*(someloop[115]-cellx[i,2])*var[i,33]+var[9]*someloop[112]*(someloop[113]-cellx[i,1])*var[i,33]+var[i,15]
  
! update flux expression outside main loop
! var[j,27]
  
  flux_direction = nint(sign(1.d0,var(27)%funk(nsvar(27,j))%v))
! sum is conducted around region <upwindfaceicells>
  do ns = (3-flux_direction)/2, (3-flux_direction)/2
    i = face(j)%icell(ns)
    call update_someloop(112,i,j)
    call update_someloop(113,i,j)
    call update_someloop(114,i,j)
    call update_someloop(115,i,j)
    call update_someloop(116,i,j)
    call update_someloop(117,i,j)
    
    someloop(94)%v = someloop(94)%v + (var(9)%funk(1)%v*someloop(116)%v*(someloop(117)%v-cell(i)%x(3))*&
      &var(33)%funk(nsvar(33,i))%v+var(9)%funk(1)%v*someloop(114)%v*(someloop(115)%v-cell(i)%x(2))&
      &*var(33)%funk(nsvar(33,i))%v+var(9)%funk(1)%v*someloop(112)%v*(someloop(113)%v-cell(i)%x(1)&
      &)*var(33)%funk(nsvar(33,i))%v+var(15)%funk(nsvar(15,i))%v)
    
    deriv = 1
    call add_to_dv(someloop(94),deriv,var(15)%funk(nsvar(15,i)))
    
    deriv = var(9)%funk(1)%v*someloop(116)%v*(someloop(117)%v-cell(i)%x(3))+var(9)%funk(1)%v*someloop(1&
      &14)%v*(someloop(115)%v-cell(i)%x(2))+var(9)%funk(1)%v*someloop(112)%v*(someloop(113)%v-cell&
      &(i)%x(1))
    call add_to_dv(someloop(94),deriv,var(33)%funk(nsvar(33,i)))
    
    deriv = var(9)%funk(1)%v*(someloop(113)%v-cell(i)%x(1))*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(112))
    
    deriv = var(9)%funk(1)%v*someloop(112)%v*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(113))
    
    deriv = var(9)%funk(1)%v*(someloop(115)%v-cell(i)%x(2))*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(114))
    
    deriv = var(9)%funk(1)%v*someloop(114)%v*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(115))
    
    deriv = var(9)%funk(1)%v*(someloop(117)%v-cell(i)%x(3))*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(116))
    
    deriv = var(9)%funk(1)%v*someloop(116)%v*var(33)%funk(nsvar(33,i))%v
    call add_to_dv(someloop(94),deriv,someloop(117))
    
  end do
  
else if (m == 95) then
! someloop SYSTEM generated sum someloop over cell region <upwindfaceicells>
! SYSTEM generated sum someloop over cell region <upwindfaceicells>
! var[9]*someloop[122]*(someloop[123]-cellx[i,3])*var[i,34]+var[9]*someloop[120]*(someloop[121]-cellx[i,2])*var[i,34]+var[9]*someloop[118]*(someloop[119]-cellx[i,1])*var[i,34]+var[i,16]
  
! update flux expression outside main loop
! var[j,27]
  
  flux_direction = nint(sign(1.d0,var(27)%funk(nsvar(27,j))%v))
! sum is conducted around region <upwindfaceicells>
  do ns = (3-flux_direction)/2, (3-flux_direction)/2
    i = face(j)%icell(ns)
    call update_someloop(118,i,j)
    call update_someloop(119,i,j)
    call update_someloop(120,i,j)
    call update_someloop(121,i,j)
    call update_someloop(122,i,j)
    call update_someloop(123,i,j)
    
    someloop(95)%v = someloop(95)%v + (var(9)%funk(1)%v*someloop(122)%v*(someloop(123)%v-cell(i)%x(3))*&
      &var(34)%funk(nsvar(34,i))%v+var(9)%funk(1)%v*someloop(120)%v*(someloop(121)%v-cell(i)%x(2))&
      &*var(34)%funk(nsvar(34,i))%v+var(9)%funk(1)%v*someloop(118)%v*(someloop(119)%v-cell(i)%x(1)&
      &)*var(34)%funk(nsvar(34,i))%v+var(16)%funk(nsvar(16,i))%v)
    
    deriv = 1
    call add_to_dv(someloop(95),deriv,var(16)%funk(nsvar(16,i)))
    
    deriv = var(9)%funk(1)%v*someloop(122)%v*(someloop(123)%v-cell(i)%x(3))+var(9)%funk(1)%v*someloop(1&
      &20)%v*(someloop(121)%v-cell(i)%x(2))+var(9)%funk(1)%v*someloop(118)%v*(someloop(119)%v-cell&
      &(i)%x(1))
    call add_to_dv(someloop(95),deriv,var(34)%funk(nsvar(34,i)))
    
    deriv = var(9)%funk(1)%v*(someloop(119)%v-cell(i)%x(1))*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(118))
    
    deriv = var(9)%funk(1)%v*someloop(118)%v*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(119))
    
    deriv = var(9)%funk(1)%v*(someloop(121)%v-cell(i)%x(2))*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(120))
    
    deriv = var(9)%funk(1)%v*someloop(120)%v*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(121))
    
    deriv = var(9)%funk(1)%v*(someloop(123)%v-cell(i)%x(3))*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(122))
    
    deriv = var(9)%funk(1)%v*someloop(122)%v*var(34)%funk(nsvar(34,i))%v
    call add_to_dv(someloop(95),deriv,someloop(123))
    
  end do
  
else if (m == 96) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,18]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(96)%v = someloop(96)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(96),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 97) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! SYSTEM generated sum someloop over cell region <facekernel[l=0]>
! var[i,18]*facekernel[j,0,ns]
  
! sum is conducted around region <facekernel[l=0]>
  do ns = 1, ubound(face(j)%kernel(0)%ijk,1)
    i = face(j)%kernel(0)%ijk(ns)
    
    someloop(97)%v = someloop(97)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(0)%v(ns))
    
    deriv = face(j)%kernel(0)%v(ns)
    call add_to_dv(someloop(97),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 98) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(98)%v = someloop(98)%v + (face(j)%norm(1,1))
    
  end do
  
else if (m == 99) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(99)%v = someloop(99)%v + (face(j)%norm(2,1))
    
  end do
  
else if (m == 100) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(100)%v = someloop(100)%v + (face(j)%norm(3,1))
    
  end do
  
else if (m == 101) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(101)%v = someloop(101)%v + (face(j)%norm(1,1))
    
  end do
  
else if (m == 102) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(102)%v = someloop(102)%v + (face(j)%norm(2,1))
    
  end do
  
else if (m == 103) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facenorm[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(103)%v = someloop(103)%v + (face(j)%norm(3,1))
    
  end do
  
else if (m == 104) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facetang1[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(104)%v = someloop(104)%v + (face(j)%norm(1,2))
    
  end do
  
else if (m == 105) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facetang1[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(105)%v = someloop(105)%v + (face(j)%norm(2,2))
    
  end do
  
else if (m == 106) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facetang1[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(106)%v = someloop(106)%v + (face(j)%norm(3,2))
    
  end do
  
else if (m == 107) then
! someloop SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! SYSTEM generated sum someloop over cell region <facekernel[l=4]>
! var[i,18]*facekernel[j,4,ns]
  
! sum is conducted around region <facekernel[l=4]>
  do ns = 1, ubound(face(j)%kernel(4)%ijk,1)
    i = face(j)%kernel(4)%ijk(ns)
    
    someloop(107)%v = someloop(107)%v + (var(18)%funk(nsvar(18,i))%v*face(j)%kernel(4)%v(ns))
    
    deriv = face(j)%kernel(4)%v(ns)
    call add_to_dv(someloop(107),deriv,var(18)%funk(nsvar(18,i)))
    
  end do
  
else if (m == 108) then
! someloop SYSTEM generated min someloop over cell region <noloop>
! SYSTEM generated min someloop over cell region <noloop>
! -var[i,15]
  
! update default expression outside main loop
! 0.d0
  
  someloop(108)%v = 0.0
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    if (-var(15)%funk(nsvar(15,i))%v<someloop(108)%v) then
      call reset_funk(someloop(m))
      someloop(108)%v = -var(15)%funk(nsvar(15,i))%v
      
      deriv = -1
      call add_to_dv(someloop(108),deriv,var(15)%funk(nsvar(15,i)))
      
    end if
  end do
  
else if (m == 109) then
! someloop SYSTEM generated min someloop over face region <celljfaces>
! SYSTEM generated min someloop over face region <celljfaces>
! someloop[128]*(facex[j,3]-someloop[129])+someloop[126]*(facex[j,2]-someloop[127])+someloop[124]*(facex[j,1]-someloop[125])
  
! update default expression outside main loop
! 1.d+20
  
  someloop(109)%v = 1.e+20
  
! sum is conducted around region <celljfaces>
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(124,i,j)
    call update_someloop(125,i,j)
    call update_someloop(126,i,j)
    call update_someloop(127,i,j)
    call update_someloop(128,i,j)
    call update_someloop(129,i,j)
    
    if (someloop(128)%v*(face(j)%x(3)-someloop(129)%v)+someloop(126)%v*(face(j)%x(2)-someloop(127)%v)+s&
      &omeloop(124)%v*(face(j)%x(1)-someloop(125)%v)<someloop(109)%v) then
    call reset_funk(someloop(m))
    someloop(109)%v = someloop(128)%v*(face(j)%x(3)-someloop(129)%v)+someloop(126)%v*(face(j)%x(2)-some&
      &loop(127)%v)+someloop(124)%v*(face(j)%x(1)-someloop(125)%v)
    
    deriv = face(j)%x(1)-someloop(125)%v
    call add_to_dv(someloop(109),deriv,someloop(124))
    
    deriv = -someloop(124)%v
    call add_to_dv(someloop(109),deriv,someloop(125))
    
    deriv = face(j)%x(2)-someloop(127)%v
    call add_to_dv(someloop(109),deriv,someloop(126))
    
    deriv = -someloop(126)%v
    call add_to_dv(someloop(109),deriv,someloop(127))
    
    deriv = face(j)%x(3)-someloop(129)%v
    call add_to_dv(someloop(109),deriv,someloop(128))
    
    deriv = -someloop(128)%v
    call add_to_dv(someloop(109),deriv,someloop(129))
    
  end if
end do

else if (m == 110) then
! someloop SYSTEM generated min someloop over cell region <noloop>
! SYSTEM generated min someloop over cell region <noloop>
! -var[i,16]
  
! update default expression outside main loop
! 0.d0
  
  someloop(110)%v = 0.0
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    if (-var(16)%funk(nsvar(16,i))%v<someloop(110)%v) then
      call reset_funk(someloop(m))
      someloop(110)%v = -var(16)%funk(nsvar(16,i))%v
      
      deriv = -1
      call add_to_dv(someloop(110),deriv,var(16)%funk(nsvar(16,i)))
      
    end if
  end do
  
else if (m == 111) then
! someloop SYSTEM generated min someloop over face region <celljfaces>
! SYSTEM generated min someloop over face region <celljfaces>
! someloop[134]*(facex[j,3]-someloop[135])+someloop[132]*(facex[j,2]-someloop[133])+someloop[130]*(facex[j,1]-someloop[131])
  
! update default expression outside main loop
! 1.d+20
  
  someloop(111)%v = 1.e+20
  
! sum is conducted around region <celljfaces>
  do ns = 1, ubound(cell(i)%jface,1)
    j = cell(i)%jface(ns)
    call update_someloop(130,i,j)
    call update_someloop(131,i,j)
    call update_someloop(132,i,j)
    call update_someloop(133,i,j)
    call update_someloop(134,i,j)
    call update_someloop(135,i,j)
    
    if (someloop(134)%v*(face(j)%x(3)-someloop(135)%v)+someloop(132)%v*(face(j)%x(2)-someloop(133)%v)+s&
      &omeloop(130)%v*(face(j)%x(1)-someloop(131)%v)<someloop(111)%v) then
    call reset_funk(someloop(m))
    someloop(111)%v = someloop(134)%v*(face(j)%x(3)-someloop(135)%v)+someloop(132)%v*(face(j)%x(2)-some&
      &loop(133)%v)+someloop(130)%v*(face(j)%x(1)-someloop(131)%v)
    
    deriv = face(j)%x(1)-someloop(131)%v
    call add_to_dv(someloop(111),deriv,someloop(130))
    
    deriv = -someloop(130)%v
    call add_to_dv(someloop(111),deriv,someloop(131))
    
    deriv = face(j)%x(2)-someloop(133)%v
    call add_to_dv(someloop(111),deriv,someloop(132))
    
    deriv = -someloop(132)%v
    call add_to_dv(someloop(111),deriv,someloop(133))
    
    deriv = face(j)%x(3)-someloop(135)%v
    call add_to_dv(someloop(111),deriv,someloop(134))
    
    deriv = -someloop(134)%v
    call add_to_dv(someloop(111),deriv,someloop(135))
    
  end if
end do

else if (m == 112) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,15]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(112)%v = someloop(112)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(112),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 113) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(113)%v = someloop(113)%v + (face(j)%x(1))
    
  end do
  
else if (m == 114) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,15]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(114)%v = someloop(114)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(114),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 115) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(115)%v = someloop(115)%v + (face(j)%x(2))
    
  end do
  
else if (m == 116) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,15]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(116)%v = someloop(116)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(116),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 117) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(117)%v = someloop(117)%v + (face(j)%x(3))
    
  end do
  
else if (m == 118) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,16]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(118)%v = someloop(118)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(118),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 119) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,1]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(119)%v = someloop(119)%v + (face(j)%x(1))
    
  end do
  
else if (m == 120) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,16]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(120)%v = someloop(120)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(120),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 121) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,2]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(121)%v = someloop(121)%v + (face(j)%x(2))
    
  end do
  
else if (m == 122) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,16]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(122)%v = someloop(122)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(122),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 123) then
! someloop SYSTEM generated sum someloop over face region <noloop>
! SYSTEM generated sum someloop over face region <noloop>
! facex[j,3]
  
! region is <noloop> with centring face so dummy loop is performed
  do ns = 1, 1
    
    someloop(123)%v = someloop(123)%v + (face(j)%x(3))
    
  end do
  
else if (m == 124) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[136]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(136,i,j)
    
    someloop(124)%v = someloop(124)%v + (someloop(136)%v)
    
    deriv = 1
    call add_to_dv(someloop(124),deriv,someloop(136))
    
  end do
  
else if (m == 125) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,1]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(125)%v = someloop(125)%v + (cell(i)%x(1))
    
  end do
  
else if (m == 126) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[137]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(137,i,j)
    
    someloop(126)%v = someloop(126)%v + (someloop(137)%v)
    
    deriv = 1
    call add_to_dv(someloop(126),deriv,someloop(137))
    
  end do
  
else if (m == 127) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,2]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(127)%v = someloop(127)%v + (cell(i)%x(2))
    
  end do
  
else if (m == 128) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[138]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(138,i,j)
    
    someloop(128)%v = someloop(128)%v + (someloop(138)%v)
    
    deriv = 1
    call add_to_dv(someloop(128),deriv,someloop(138))
    
  end do
  
else if (m == 129) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,3]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(129)%v = someloop(129)%v + (cell(i)%x(3))
    
  end do
  
else if (m == 130) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[139]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(139,i,j)
    
    someloop(130)%v = someloop(130)%v + (someloop(139)%v)
    
    deriv = 1
    call add_to_dv(someloop(130),deriv,someloop(139))
    
  end do
  
else if (m == 131) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,1]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(131)%v = someloop(131)%v + (cell(i)%x(1))
    
  end do
  
else if (m == 132) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[140]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(140,i,j)
    
    someloop(132)%v = someloop(132)%v + (someloop(140)%v)
    
    deriv = 1
    call add_to_dv(someloop(132),deriv,someloop(140))
    
  end do
  
else if (m == 133) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,2]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(133)%v = someloop(133)%v + (cell(i)%x(2))
    
  end do
  
else if (m == 134) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! someloop[141]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    call update_someloop(141,i,j)
    
    someloop(134)%v = someloop(134)%v + (someloop(141)%v)
    
    deriv = 1
    call add_to_dv(someloop(134),deriv,someloop(141))
    
  end do
  
else if (m == 135) then
! someloop SYSTEM generated sum someloop over cell region <noloop>
! SYSTEM generated sum someloop over cell region <noloop>
! cellx[i,3]
  
! region is <noloop> with centring cell so dummy loop is performed
  do ns = 1, 1
    
    someloop(135)%v = someloop(135)%v + (cell(i)%x(3))
    
  end do
  
else if (m == 136) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,15]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(136)%v = someloop(136)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(136),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 137) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,15]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(137)%v = someloop(137)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(137),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 138) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,15]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(138)%v = someloop(138)%v + (var(15)%funk(nsvar(15,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(138),deriv,var(15)%funk(nsvar(15,i)))
    
  end do
  
else if (m == 139) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=1]>
! var[i,16]*cellkernel[ilast,1,ns]
  
! sum is conducted around region <cellkernel[l=1]>
  do ns = 1, ubound(cell(ilast)%kernel(1)%ijk,1)
    i = cell(ilast)%kernel(1)%ijk(ns)
    
    someloop(139)%v = someloop(139)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(1)%v(ns))
    
    deriv = cell(ilast)%kernel(1)%v(ns)
    call add_to_dv(someloop(139),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 140) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=2]>
! var[i,16]*cellkernel[ilast,2,ns]
  
! sum is conducted around region <cellkernel[l=2]>
  do ns = 1, ubound(cell(ilast)%kernel(2)%ijk,1)
    i = cell(ilast)%kernel(2)%ijk(ns)
    
    someloop(140)%v = someloop(140)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(2)%v(ns))
    
    deriv = cell(ilast)%kernel(2)%v(ns)
    call add_to_dv(someloop(140),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
else if (m == 141) then
! someloop SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! SYSTEM generated sum someloop over cell region <cellkernel[l=3]>
! var[i,16]*cellkernel[ilast,3,ns]
  
! sum is conducted around region <cellkernel[l=3]>
  do ns = 1, ubound(cell(ilast)%kernel(3)%ijk,1)
    i = cell(ilast)%kernel(3)%ijk(ns)
    
    someloop(141)%v = someloop(141)%v + (var(16)%funk(nsvar(16,i))%v*cell(ilast)%kernel(3)%v(ns))
    
    deriv = cell(ilast)%kernel(3)%v(ns)
    call add_to_dv(someloop(141),deriv,var(16)%funk(nsvar(16,i)))
    
  end do
  
  
else
  write(*,*) "ERROR: the index ",m," was not found when updating someloop"
  stop
end if


if (debug) write(*,'(a/80(1h-))') 'subroutine update_someloop'

end subroutine update_someloop

!----------------------------------------------------------------------------

subroutine update_constants

! here we update all the constants that are calculated using equations

use general_module
integer :: nvar, m, ns, i, j
double precision :: deriv
character(len=1000) :: formatline
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine update_constants'

do nvar = 1, allocatable_size(var_list(var_list_number(centring="all",type="constant"))%list)
  m = var_list(var_list_number(centring="all",type="constant"))%list(nvar)

  i = 0
  j = 0

  if (debug) write(*,*) 'updating var constant: m = ',m,': name = ',trim(var(m)%name),': centring = ',var(m)%centring

! equations
!  <sub_string:constant>

  if (debug) then
    formatline = '(a,'//trim(indexformat)//',a,i3,a,a)'
    do ns = 1, ubound(var(m)%funk,1)
      write(*,fmt=formatline) '(ns,m) = (',ns,',',m,'): var = ',trim(print_funk(var(m)%funk(ns)))
    end do
  end if

end do

if (debug) write(*,'(a/80(1h-))') 'subroutine update_constants'

end subroutine update_constants

!----------------------------------------------------------------------------

subroutine update_independents

! here we update all the independent initial values

use general_module
integer :: nvar, m, ns, i, j
double precision :: deriv
character(len=1000) :: formatline
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine update_independents'

do nvar = 1, allocatable_size(var_list(var_list_number(centring="all",type="independent"))%list)
  m = var_list(var_list_number(centring="all",type="independent"))%list(nvar)

  i = 0
  j = 0

  if (debug) write(*,*) 'updating var independent: m = ',m,': name = ',trim(var(m)%name),': centring = ',var(m)%centring

! equations
  if (m == 11) then
! independent <u[l=1]>
! 1.d0
! 1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(11)%funk(ns)%v = var(11)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 12) then
! independent <u[l=2]>
! 0.d0
! 0.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(12)%funk(ns)%v = var(12)%funk(ns)%v + (0.0)
    end do
    
  else if (m == 13) then
! independent <p>
! 1.d0
! 1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(13)%funk(ns)%v = var(13)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 14) then
! independent <p_in>
! 1.d0
! 1.0
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      
      var(14)%funk(ns)%v = var(14)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 15) then
! independent <n+>
! 1.d0
! 1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(15)%funk(ns)%v = var(15)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 16) then
! independent <n->
! 1.d0
! 1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(16)%funk(ns)%v = var(16)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 17) then
! independent <dUdx inlet>
! 1.d0
! 1.0
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      
      var(17)%funk(ns)%v = var(17)%funk(ns)%v + (1.0)
    end do
    
  else if (m == 18) then
! independent <U>
! 1.d0
! 1.0
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(18)%funk(ns)%v = var(18)%funk(ns)%v + (1.0)
    end do
    
    
  else
    write(*,*) "ERROR: the index ",m," was not found when updating independent"
    stop
  end if


  if (debug) then
    formatline = '(a,'//trim(indexformat)//',a,i3,a,a)'
    do ns = 1, ubound(var(m)%funk,1)
      write(*,fmt=formatline) '(ns,m) = (',ns,',',m,'): var = ',trim(print_funk(var(m)%funk(ns)))
    end do
  end if

end do

if (debug) write(*,'(a/80(1h-))') 'subroutine update_independents'

end subroutine update_independents

!----------------------------------------------------------------------------

subroutine update_outputs

! here we update all the outputs that are calculated using equations

use general_module
integer :: nvar, m, ns, i, j
double precision :: deriv
character(len=1000) :: formatline
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine update_outputs'

do nvar = 1, allocatable_size(var_list(var_list_number(centring="all",type="output"))%list)
  m = var_list(var_list_number(centring="all",type="output"))%list(nvar)

  i = 0
  j = 0

  if (debug) write(*,*) 'updating var output: m = ',m,': name = ',trim(var(m)%name),': centring = ',var(m)%centring

! equations
  if (m == 76) then
! output <n_0>
! sqrt(<n+>*<n->)
! sqrt(var[i,15]*var[i,16])
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(76)%funk(ns)%v = var(76)%funk(ns)%v + (sqrt(var(15)%funk(nsvar(15,i))%v*var(16)%funk(nsvar(16,i&
        &))%v))
    end do
    
  else if (m == 77) then
! output <rho_e>
! <n+>-<n->
! var[i,15]-var[i,16]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(77)%funk(ns)%v = var(77)%funk(ns)%v + (var(15)%funk(nsvar(15,i))%v-var(16)%funk(nsvar(16,i))%v)
    end do
    
  else if (m == 78) then
! output <n+ error>
! <n+>-<n+ lim>
! var[i,15]-var[i,31]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(78)%funk(ns)%v = var(78)%funk(ns)%v + (var(15)%funk(nsvar(15,i))%v-var(31)%funk(nsvar(31,i))%v)
    end do
    
  else if (m == 79) then
! output <n- error>
! <n->-<n- lim>
! var[i,16]-var[i,32]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(79)%funk(ns)%v = var(79)%funk(ns)%v + (var(16)%funk(nsvar(16,i))%v-var(32)%funk(nsvar(32,i))%v)
    end do
    
  else if (m == 80) then
! output <grad rho_e[l=1]>
! cellgrad[l=1](<rho_e>)
! someloop[72]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(72,i,j)
      
      var(80)%funk(ns)%v = var(80)%funk(ns)%v + (someloop(72)%v)
    end do
    
  else if (m == 81) then
! output <grad rho_e[l=2]>
! cellgrad[l=2](<rho_e>)
! someloop[73]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(73,i,j)
      
      var(81)%funk(ns)%v = var(81)%funk(ns)%v + (someloop(73)%v)
    end do
    
  else if (m == 82) then
! output <grad rho_e[l=3]>
! cellgrad[l=3](<rho_e>)
! someloop[74]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(74,i,j)
      
      var(82)%funk(ns)%v = var(82)%funk(ns)%v + (someloop(74)%v)
    end do
    
  else if (m == 83) then
! output <grad rho_e mag>
! sqrt(dot(<grad rho_e[l=:]>,<grad rho_e[l=:]>))
! sqrt(var[i,82]^2+var[i,81]^2+var[i,80]^2)
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      
      var(83)%funk(ns)%v = var(83)%funk(ns)%v + (sqrt(var(82)%funk(nsvar(82,i))%v**2+var(81)%funk(nsvar(8&
        &1,i))%v**2+var(80)%funk(nsvar(80,i))%v**2))
    end do
    
  else if (m == 84) then
! output <grad rho_e av>
! cellsum(<grad rho_e mag>,<all cells>)/cellsum(1.d0,<all cells>)
! someloop[75]/someloop[76]
    
    do ns = 1, 1
      call reset_funk(var(m)%funk(ns))
      call update_someloop(75,i,j)
      call update_someloop(76,i,j)
      
      var(84)%funk(ns)%v = var(84)%funk(ns)%v + (someloop(75)%v/someloop(76)%v)
    end do
    
  else if (m == 85) then
! output <mesh rho_e>
! <grad rho_e av>/cellmax(<grad rho_e mag>,<grad rho_e av>)
! var[84]/someloop[77]
    
    do ns = 1, ubound(region(var(m)%region_number)%ij,1)
      i = region(var(m)%region_number)%ij(ns)
      call reset_funk(var(m)%funk(ns))
      call update_someloop(77,i,j)
      
      var(85)%funk(ns)%v = var(85)%funk(ns)%v + (var(84)%funk(1)%v/someloop(77)%v)
    end do
    
    
  else
    write(*,*) "ERROR: the index ",m," was not found when updating output"
    stop
  end if


  if (debug) then
    formatline = '(a,'//trim(indexformat)//',a,i3,a,a)'
    do ns = 1, ubound(var(m)%funk,1)
      write(*,fmt=formatline) '(ns,m) = (',ns,',',m,'): var = ',trim(print_funk(var(m)%funk(ns)))
    end do
  end if

end do

if (debug) write(*,'(a/80(1h-))') 'subroutine update_outputs'

end subroutine update_outputs

!----------------------------------------------------------------------------

subroutine variable_checker(error)

! here we check on the magnitudes of any variables against specified options

use general_module
integer :: ns, error
logical :: debug = .false.
                  
if (debug) write(*,'(80(1h+)/a)') 'subroutine variable_checker'

!<sub_string:variable_checker>

if (debug) write(*,'(a/80(1h-))') 'subroutine variable_checker'

end subroutine variable_checker

!----------------------------------------------------------------------------

end module equations_module

!----------------------------------------------------------------------------
